# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: github.com/metaprov/modelaapi/services/dbproxyd/v1/dbproxyd.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1 import generated_pb2 as github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_infra_dot_v1alpha1_dot_generated__pb2
from github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1 import generated_pb2 as github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_data_dot_v1alpha1_dot_generated__pb2
from github.com.metaprov.modelaapi.pkg.apis.inference.v1alpha1 import generated_pb2 as github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_inference_dot_v1alpha1_dot_generated__pb2
from github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1 import generated_pb2 as github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_training_dot_v1alpha1_dot_generated__pb2
from github.com.metaprov.modelaapi.pkg.apis.team.v1alpha1 import generated_pb2 as github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_team_dot_v1alpha1_dot_generated__pb2
from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nAgithub.com/metaprov/modelaapi/services/dbproxyd/v1/dbproxyd.proto\x12\x32github.com.metaprov.modelaapi.services.dbproxyd.v1\x1a\x1cgoogle/api/annotations.proto\x1a\x45github.com/metaprov/modelaapi/pkg/apis/infra/v1alpha1/generated.proto\x1a\x44github.com/metaprov/modelaapi/pkg/apis/data/v1alpha1/generated.proto\x1aIgithub.com/metaprov/modelaapi/pkg/apis/inference/v1alpha1/generated.proto\x1aHgithub.com/metaprov/modelaapi/pkg/apis/training/v1alpha1/generated.proto\x1a\x44github.com/metaprov/modelaapi/pkg/apis/team/v1alpha1/generated.proto\x1a\x1bgoogle/protobuf/empty.proto\"O\n\x13ListAccountsRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x11\n\tpage_size\x18\x02 \x01(\x05\x12\x12\n\npage_token\x18\x03 \x01(\t\"~\n\x14ListAccountsResponse\x12M\n\x05items\x18\x01 \x03(\x0b\x32>.github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1.Account\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"4\n\x11GetAccountRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"d\n\x14\x43reateAccountRequest\x12L\n\x04item\x18\x01 \x01(\x0b\x32>.github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1.Account\"d\n\x14UpdateAccountRequest\x12L\n\x04item\x18\x02 \x01(\x0b\x32>.github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1.Account\"7\n\x14\x44\x65leteAccountRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"M\n\x11ListAlertsRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x11\n\tpage_size\x18\x02 \x01(\x05\x12\x12\n\npage_token\x18\x03 \x01(\t\"z\n\x12ListAlertsResponse\x12K\n\x05items\x18\x01 \x03(\x0b\x32<.github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1.Alert\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"2\n\x0fGetAlertRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"`\n\x12\x43reateAlertRequest\x12J\n\x04item\x18\x01 \x01(\x0b\x32<.github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1.Alert\"`\n\x12UpdateAlertRequest\x12J\n\x04item\x18\x02 \x01(\x0b\x32<.github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1.Alert\"5\n\x12\x44\x65leteAlertRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"R\n\x16ListAttachmentsRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x11\n\tpage_size\x18\x02 \x01(\x05\x12\x12\n\npage_token\x18\x03 \x01(\t\"\x84\x01\n\x17ListAttachmentsResponse\x12P\n\x05items\x18\x01 \x03(\x0b\x32\x41.github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1.Attachment\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"7\n\x14GetAttachmentRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"j\n\x17\x43reateAttachmentRequest\x12O\n\x04item\x18\x01 \x01(\x0b\x32\x41.github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1.Attachment\"j\n\x17UpdateAttachmentRequest\x12O\n\x04item\x18\x02 \x01(\x0b\x32\x41.github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1.Attachment\":\n\x17\x44\x65leteAttachmentRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"L\n\x10ListTodosRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x11\n\tpage_size\x18\x02 \x01(\x05\x12\x12\n\npage_token\x18\x03 \x01(\t\"w\n\x11ListTodosResponse\x12I\n\x05items\x18\x01 \x03(\x0b\x32:.github.com.metaprov.modelaapi.pkg.apis.team.v1alpha1.Todo\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"1\n\x0eGetTodoRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"]\n\x11\x43reateTodoRequest\x12H\n\x04item\x18\x01 \x01(\x0b\x32:.github.com.metaprov.modelaapi.pkg.apis.team.v1alpha1.Todo\"]\n\x11UpdateTodoRequest\x12H\n\x04item\x18\x02 \x01(\x0b\x32:.github.com.metaprov.modelaapi.pkg.apis.team.v1alpha1.Todo\"4\n\x11\x44\x65leteTodoRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"R\n\x16ListConnectionsRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x11\n\tpage_size\x18\x02 \x01(\x05\x12\x12\n\npage_token\x18\x03 \x01(\t\"\x84\x01\n\x17ListConnectionsResponse\x12P\n\x05items\x18\x01 \x03(\x0b\x32\x41.github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1.Connection\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"7\n\x14GetConnectionRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"j\n\x17\x43reateConnectionRequest\x12O\n\x04item\x18\x02 \x01(\x0b\x32\x41.github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1.Connection\"j\n\x17UpdateConnectionRequest\x12O\n\x04item\x18\x02 \x01(\x0b\x32\x41.github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1.Connection\":\n\x17\x44\x65leteConnectionRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"K\n\x0fListLabsRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x11\n\tpage_size\x18\x02 \x01(\x05\x12\x12\n\npage_token\x18\x03 \x01(\t\"v\n\x10ListLabsResponse\x12I\n\x05items\x18\x01 \x03(\x0b\x32:.github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1.Lab\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"0\n\rGetLabRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"\\\n\x10\x43reateLabRequest\x12H\n\x04item\x18\x01 \x01(\x0b\x32:.github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1.Lab\"\\\n\x10UpdateLabRequest\x12H\n\x04item\x18\x01 \x01(\x0b\x32:.github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1.Lab\"3\n\x10\x44\x65leteLabRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"O\n\x13ListLicensesRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x11\n\tpage_size\x18\x02 \x01(\x05\x12\x12\n\npage_token\x18\x03 \x01(\t\"~\n\x14ListLicensesResponse\x12M\n\x05items\x18\x01 \x03(\x0b\x32>.github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1.License\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"4\n\x11GetLicenseRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"d\n\x14\x43reateLicenseRequest\x12L\n\x04item\x18\x01 \x01(\x0b\x32>.github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1.License\"d\n\x14UpdateLicenseRequest\x12L\n\x04item\x18\x01 \x01(\x0b\x32>.github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1.License\"7\n\x14\x44\x65leteLicenseRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"P\n\x14ListNotifiersRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x11\n\tpage_size\x18\x02 \x01(\x05\x12\x12\n\npage_token\x18\x03 \x01(\t\"\x80\x01\n\x15ListNotifiersResponse\x12N\n\x05items\x18\x01 \x03(\x0b\x32?.github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1.Notifier\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"5\n\x12GetNotifierRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"f\n\x15\x43reateNotifierRequest\x12M\n\x04item\x18\x01 \x01(\x0b\x32?.github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1.Notifier\"f\n\x15UpdateNotifierRequest\x12M\n\x04item\x18\x01 \x01(\x0b\x32?.github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1.Notifier\"8\n\x15\x44\x65leteNotifierRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"S\n\x17ListServingsitesRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x11\n\tpage_size\x18\x02 \x01(\x05\x12\x12\n\npage_token\x18\x03 \x01(\t\"\x86\x01\n\x18ListServingsitesResponse\x12Q\n\x05items\x18\x01 \x03(\x0b\x32\x42.github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1.ServingSite\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"8\n\x15GetServingsiteRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"l\n\x18\x43reateServingsiteRequest\x12P\n\x04item\x18\x01 \x01(\x0b\x32\x42.github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1.ServingSite\"l\n\x18UpdateServingsiteRequest\x12P\n\x04item\x18\x01 \x01(\x0b\x32\x42.github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1.ServingSite\";\n\x18\x44\x65leteServingsiteRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"N\n\x12ListTenantsRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x11\n\tpage_size\x18\x02 \x01(\x05\x12\x12\n\npage_token\x18\x03 \x01(\t\"|\n\x13ListTenantsResponse\x12L\n\x05items\x18\x01 \x03(\x0b\x32=.github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1.Tenant\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"3\n\x10GetTenantRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"b\n\x13\x43reateTenantRequest\x12K\n\x04item\x18\x01 \x01(\x0b\x32=.github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1.Tenant\"b\n\x13UpdateTenantRequest\x12K\n\x04item\x18\x01 \x01(\x0b\x32=.github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1.Tenant\"6\n\x13\x44\x65leteTenantRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"U\n\x19ListVirtualBucketsRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x11\n\tpage_size\x18\x02 \x01(\x05\x12\x12\n\npage_token\x18\x03 \x01(\t\"\x8a\x01\n\x1aListVirtualBucketsResponse\x12S\n\x05items\x18\x01 \x03(\x0b\x32\x44.github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1.VirtualBucket\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\":\n\x17GetVirtualBucketRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"p\n\x1a\x43reateVirtualBucketRequest\x12R\n\x04item\x18\x01 \x01(\x0b\x32\x44.github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1.VirtualBucket\"p\n\x1aUpdateVirtualBucketRequest\x12R\n\x04item\x18\x01 \x01(\x0b\x32\x44.github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1.VirtualBucket\"=\n\x1a\x44\x65leteVirtualBucketRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"T\n\x18ListDataPipelinesRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x11\n\tpage_size\x18\x02 \x01(\x05\x12\x12\n\npage_token\x18\x03 \x01(\t\"\x87\x01\n\x19ListDataPipelinesResponse\x12Q\n\x05items\x18\x01 \x03(\x0b\x32\x42.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.DataPipeline\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"9\n\x16GetDataPipelineRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"m\n\x19\x43reateDataPipelineRequest\x12P\n\x04item\x18\x01 \x01(\x0b\x32\x42.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.DataPipeline\"m\n\x19UpdateDataPipelineRequest\x12P\n\x04item\x18\x01 \x01(\x0b\x32\x42.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.DataPipeline\"<\n\x19\x44\x65leteDataPipelineRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"W\n\x1bListDataPipelineRunsRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x11\n\tpage_size\x18\x02 \x01(\x05\x12\x12\n\npage_token\x18\x03 \x01(\t\"\x8d\x01\n\x1cListDataPipelineRunsResponse\x12T\n\x05items\x18\x01 \x03(\x0b\x32\x45.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.DataPipelineRun\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"<\n\x19GetDataPipelineRunRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"s\n\x1c\x43reateDataPipelineRunRequest\x12S\n\x04item\x18\x01 \x01(\x0b\x32\x45.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.DataPipelineRun\"s\n\x1cUpdateDataPipelineRunRequest\x12S\n\x04item\x18\x01 \x01(\x0b\x32\x45.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.DataPipelineRun\"?\n\x1c\x44\x65leteDataPipelineRunRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"S\n\x17ListDataProductsRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x11\n\tpage_size\x18\x02 \x01(\x05\x12\x12\n\npage_token\x18\x03 \x01(\t\"\x85\x01\n\x18ListDataProductsResponse\x12P\n\x05items\x18\x01 \x03(\x0b\x32\x41.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.DataProduct\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"8\n\x15GetDataProductRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"k\n\x18\x43reateDataProductRequest\x12O\n\x04item\x18\x01 \x01(\x0b\x32\x41.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.DataProduct\"k\n\x18UpdateDataProductRequest\x12O\n\x04item\x18\x01 \x01(\x0b\x32\x41.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.DataProduct\";\n\x18\x44\x65leteDataProductRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"Z\n\x1eListDataProductVersionsRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x11\n\tpage_size\x18\x02 \x01(\x05\x12\x12\n\npage_token\x18\x03 \x01(\t\"\x93\x01\n\x1fListDataProductVersionsResponse\x12W\n\x05items\x18\x01 \x03(\x0b\x32H.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.DataProductVersion\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"?\n\x1cGetDataProductVersionRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"y\n\x1f\x43reateDataProductVersionRequest\x12V\n\x04item\x18\x01 \x01(\x0b\x32H.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.DataProductVersion\"y\n\x1fUpdateDataProductVersionRequest\x12V\n\x04item\x18\x01 \x01(\x0b\x32H.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.DataProductVersion\"B\n\x1f\x44\x65leteDataProductVersionRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"O\n\x13ListDatasetsRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x11\n\tpage_size\x18\x02 \x01(\x05\x12\x12\n\npage_token\x18\x03 \x01(\t\"}\n\x14ListDatasetsResponse\x12L\n\x05items\x18\x01 \x03(\x0b\x32=.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.Dataset\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"4\n\x11GetDatasetRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"c\n\x14\x43reateDatasetRequest\x12K\n\x04item\x18\x01 \x01(\x0b\x32=.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.Dataset\"c\n\x14UpdateDatasetRequest\x12K\n\x04item\x18\x01 \x01(\x0b\x32=.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.Dataset\"7\n\x14\x44\x65leteDatasetRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"R\n\x16ListDatasourcesRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x11\n\tpage_size\x18\x02 \x01(\x05\x12\x12\n\npage_token\x18\x03 \x01(\t\"\x83\x01\n\x17ListDatasourcesResponse\x12O\n\x05items\x18\x01 \x03(\x0b\x32@.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.DataSource\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"7\n\x14GetDatasourceRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"i\n\x17\x43reateDatasourceRequest\x12N\n\x04item\x18\x01 \x01(\x0b\x32@.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.DataSource\"i\n\x17UpdateDatasourceRequest\x12N\n\x04item\x18\x01 \x01(\x0b\x32@.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.DataSource\":\n\x17\x44\x65leteDatasourceRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"O\n\x13ListEntitiesRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x11\n\tpage_size\x18\x02 \x01(\x05\x12\x12\n\npage_token\x18\x03 \x01(\t\"|\n\x14ListEntitiesResponse\x12K\n\x05items\x18\x01 \x03(\x0b\x32<.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.Entity\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"3\n\x10GetEntityRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"a\n\x13\x43reateEntityRequest\x12J\n\x04item\x18\x01 \x01(\x0b\x32<.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.Entity\"a\n\x13UpdateEntityRequest\x12J\n\x04item\x18\x01 \x01(\x0b\x32<.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.Entity\"6\n\x13\x44\x65leteEntityRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"S\n\x17ListModelClassesRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x11\n\tpage_size\x18\x02 \x01(\x05\x12\x12\n\npage_token\x18\x03 \x01(\t\"\x88\x01\n\x18ListModelClassesResponse\x12S\n\x05items\x18\x01 \x03(\x0b\x32\x44.github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.ModelClass\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"V\n\x1aListModelClassesRunRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x11\n\tpage_size\x18\x02 \x01(\x05\x12\x12\n\npage_token\x18\x03 \x01(\t\"\x8e\x01\n\x1bListModelClasseRunsResponse\x12V\n\x05items\x18\x01 \x03(\x0b\x32G.github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.ModelClassRun\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"7\n\x14GetModelClassRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"m\n\x17\x43reateModelClassRequest\x12R\n\x04item\x18\x01 \x01(\x0b\x32\x44.github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.ModelClass\"m\n\x17UpdateModelClassRequest\x12R\n\x04item\x18\x01 \x01(\x0b\x32\x44.github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.ModelClass\":\n\x17\x44\x65leteModelClassRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\":\n\x17GetModelClassRunRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"s\n\x1a\x43reateModelClassRunRequest\x12U\n\x04item\x18\x01 \x01(\x0b\x32G.github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.ModelClassRun\"s\n\x1aUpdateModelClassRunRequest\x12U\n\x04item\x18\x01 \x01(\x0b\x32G.github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.ModelClassRun\"=\n\x1a\x44\x65leteModelClassRunRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"X\n\x1cListFeatureHistogramsRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x11\n\tpage_size\x18\x02 \x01(\x05\x12\x12\n\npage_token\x18\x03 \x01(\t\"\x8f\x01\n\x1dListFeatureHistogramsResponse\x12U\n\x05items\x18\x01 \x03(\x0b\x32\x46.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.FeatureHistogram\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"=\n\x1aGetFeatureHistogramRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"u\n\x1d\x43reateFeatureHistogramRequest\x12T\n\x04item\x18\x01 \x01(\x0b\x32\x46.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.FeatureHistogram\"u\n\x1dUpdateFeatureHistogramRequest\x12T\n\x04item\x18\x01 \x01(\x0b\x32\x46.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.FeatureHistogram\"@\n\x1d\x44\x65leteFeatureHistogramRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"S\n\x17ListFeatureGroupRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x11\n\tpage_size\x18\x02 \x01(\x05\x12\x12\n\npage_token\x18\x03 \x01(\t\"\x86\x01\n\x18ListFeatureGroupResponse\x12Q\n\x05items\x18\x01 \x03(\x0b\x32\x42.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.FeatureGroup\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"9\n\x16GetFeatureGroupRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"m\n\x19\x43reateFeatureGroupRequest\x12P\n\x04item\x18\x01 \x01(\x0b\x32\x42.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.FeatureGroup\"m\n\x19UpdateFeatureGroupRequest\x12P\n\x04item\x18\x01 \x01(\x0b\x32\x42.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.FeatureGroup\"<\n\x19\x44\x65leteFeatureGroupRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"N\n\x12ListRecipesRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x11\n\tpage_size\x18\x02 \x01(\x05\x12\x12\n\npage_token\x18\x03 \x01(\t\"{\n\x13ListRecipesResponse\x12K\n\x05items\x18\x01 \x03(\x0b\x32<.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.Recipe\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"3\n\x10GetRecipeRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"a\n\x13\x43reateRecipeRequest\x12J\n\x04item\x18\x01 \x01(\x0b\x32<.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.Recipe\"a\n\x13UpdateRecipeRequest\x12J\n\x04item\x18\x01 \x01(\x0b\x32<.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.Recipe\"6\n\x13\x44\x65leteRecipeRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"Q\n\x15ListRecipeRunsRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x11\n\tpage_size\x18\x02 \x01(\x05\x12\x12\n\npage_token\x18\x03 \x01(\t\"\x81\x01\n\x16ListRecipeRunsResponse\x12N\n\x05items\x18\x01 \x03(\x0b\x32?.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.RecipeRun\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"6\n\x13GetRecipeRunRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"g\n\x16\x43reateRecipeRunRequest\x12M\n\x04item\x18\x01 \x01(\x0b\x32?.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.RecipeRun\"g\n\x16UpdateRecipeRunRequest\x12M\n\x04item\x18\x01 \x01(\x0b\x32?.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.RecipeRun\"9\n\x16\x44\x65leteRecipeRunRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"M\n\x11ListModelsRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x11\n\tpage_size\x18\x02 \x01(\x05\x12\x12\n\npage_token\x18\x03 \x01(\t\"}\n\x12ListModelsResponse\x12N\n\x05items\x18\x01 \x03(\x0b\x32?.github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.Model\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"2\n\x0fGetModelRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"c\n\x12\x43reateModelRequest\x12M\n\x04item\x18\x01 \x01(\x0b\x32?.github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.Model\"c\n\x12UpdateModelRequest\x12M\n\x04item\x18\x01 \x01(\x0b\x32?.github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.Model\"5\n\x12\x44\x65leteModelRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"N\n\x12ListReportsRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x11\n\tpage_size\x18\x02 \x01(\x05\x12\x12\n\npage_token\x18\x03 \x01(\t\"\x7f\n\x13ListReportsResponse\x12O\n\x05items\x18\x01 \x03(\x0b\x32@.github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.Report\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"3\n\x10GetReportRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"e\n\x13\x43reateReportRequest\x12N\n\x04item\x18\x01 \x01(\x0b\x32@.github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.Report\"e\n\x13UpdateReportRequest\x12N\n\x04item\x18\x01 \x01(\x0b\x32@.github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.Report\"6\n\x13\x44\x65leteReportRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"N\n\x12ListStudiesRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x11\n\tpage_size\x18\x02 \x01(\x05\x12\x12\n\npage_token\x18\x03 \x01(\t\"~\n\x13ListStudiesResponse\x12N\n\x05items\x18\x01 \x03(\x0b\x32?.github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.Study\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"2\n\x0fGetStudyRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"c\n\x12\x43reateStudyRequest\x12M\n\x04item\x18\x01 \x01(\x0b\x32?.github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.Study\"c\n\x12UpdateStudyRequest\x12M\n\x04item\x18\x01 \x01(\x0b\x32?.github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.Study\"5\n\x12\x44\x65leteStudyRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"R\n\x16ListPredictionsRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x11\n\tpage_size\x18\x02 \x01(\x05\x12\x12\n\npage_token\x18\x03 \x01(\t\"\x88\x01\n\x17ListPredictionsResponse\x12T\n\x05items\x18\x01 \x03(\x0b\x32\x45.github.com.metaprov.modelaapi.pkg.apis.inference.v1alpha1.Prediction\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"7\n\x14GetPredictionRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"n\n\x17\x43reatePredictionRequest\x12S\n\x04item\x18\x01 \x01(\x0b\x32\x45.github.com.metaprov.modelaapi.pkg.apis.inference.v1alpha1.Prediction\"n\n\x17UpdatePredictionRequest\x12S\n\x04item\x18\x01 \x01(\x0b\x32\x45.github.com.metaprov.modelaapi.pkg.apis.inference.v1alpha1.Prediction\":\n\x17\x44\x65letePredictionRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"Q\n\x15ListPredictorsRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x11\n\tpage_size\x18\x02 \x01(\x05\x12\x12\n\npage_token\x18\x03 \x01(\t\"\x86\x01\n\x16ListPredictorsResponse\x12S\n\x05items\x18\x01 \x03(\x0b\x32\x44.github.com.metaprov.modelaapi.pkg.apis.inference.v1alpha1.Predictor\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"6\n\x13GetPredictorRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"l\n\x16\x43reatePredictorRequest\x12R\n\x04item\x18\x01 \x01(\x0b\x32\x44.github.com.metaprov.modelaapi.pkg.apis.inference.v1alpha1.Predictor\"l\n\x16UpdatePredictorRequest\x12R\n\x04item\x18\x01 \x01(\x0b\x32\x44.github.com.metaprov.modelaapi.pkg.apis.inference.v1alpha1.Predictor\"9\n\x16\x44\x65letePredictorRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"N\n\x12ListReviewsRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x11\n\tpage_size\x18\x02 \x01(\x05\x12\x12\n\npage_token\x18\x03 \x01(\t\"{\n\x13ListReviewsResponse\x12K\n\x05items\x18\x01 \x03(\x0b\x32<.github.com.metaprov.modelaapi.pkg.apis.team.v1alpha1.Review\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"3\n\x10GetReviewRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"a\n\x13\x43reateReviewRequest\x12J\n\x04item\x18\x01 \x01(\x0b\x32<.github.com.metaprov.modelaapi.pkg.apis.team.v1alpha1.Review\"a\n\x13UpdateReviewRequest\x12J\n\x04item\x18\x01 \x01(\x0b\x32<.github.com.metaprov.modelaapi.pkg.apis.team.v1alpha1.Review\"6\n\x13\x44\x65leteReviewRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"R\n\x16ListPostMortemsRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x11\n\tpage_size\x18\x02 \x01(\x05\x12\x12\n\npage_token\x18\x03 \x01(\t\"\x83\x01\n\x17ListPostMortemsResponse\x12O\n\x05items\x18\x01 \x03(\x0b\x32@.github.com.metaprov.modelaapi.pkg.apis.team.v1alpha1.PostMortem\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"7\n\x14GetPostMortemRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"i\n\x17\x43reatePostMortemRequest\x12N\n\x04item\x18\x01 \x01(\x0b\x32@.github.com.metaprov.modelaapi.pkg.apis.team.v1alpha1.PostMortem\"i\n\x17UpdatePostMortemRequest\x12N\n\x04item\x18\x01 \x01(\x0b\x32@.github.com.metaprov.modelaapi.pkg.apis.team.v1alpha1.PostMortem\":\n\x17\x44\x65letePostMortemRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"O\n\x13ListRunbooksRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x11\n\tpage_size\x18\x02 \x01(\x05\x12\x12\n\npage_token\x18\x03 \x01(\t\"}\n\x14ListRunbooksResponse\x12L\n\x05items\x18\x01 \x03(\x0b\x32=.github.com.metaprov.modelaapi.pkg.apis.team.v1alpha1.RunBook\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"4\n\x11GetRunbookRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"c\n\x14\x43reateRunbookRequest\x12K\n\x04item\x18\x01 \x01(\x0b\x32=.github.com.metaprov.modelaapi.pkg.apis.team.v1alpha1.RunBook\"c\n\x14UpdateRunbookRequest\x12K\n\x04item\x18\x01 \x01(\x0b\x32=.github.com.metaprov.modelaapi.pkg.apis.team.v1alpha1.RunBook\"7\n\x14\x44\x65leteRunbookRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"N\n\x12ListDataAppRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x11\n\tpage_size\x18\x02 \x01(\x05\x12\x12\n\npage_token\x18\x03 \x01(\t\"\x81\x01\n\x13ListDataAppResponse\x12Q\n\x05items\x18\x01 \x03(\x0b\x32\x42.github.com.metaprov.modelaapi.pkg.apis.inference.v1alpha1.DataApp\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"4\n\x11GetDataAppRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"h\n\x14\x43reateDataAppRequest\x12P\n\x04item\x18\x01 \x01(\x0b\x32\x42.github.com.metaprov.modelaapi.pkg.apis.inference.v1alpha1.DataApp\"h\n\x14UpdateDataAppRequest\x12P\n\x04item\x18\x01 \x01(\x0b\x32\x42.github.com.metaprov.modelaapi.pkg.apis.inference.v1alpha1.DataApp\"7\n\x14\x44\x65leteDataAppRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t2\x81\xc9\x01\n\x14\x44\x61tabaseProxyService\x12\xa3\x01\n\x0cListAccounts\x12G.github.com.metaprov.modelaapi.services.dbproxyd.v1.ListAccountsRequest\x1aH.github.com.metaprov.modelaapi.services.dbproxyd.v1.ListAccountsResponse\"\x00\x12\x95\x01\n\nGetAccount\x12\x45.github.com.metaprov.modelaapi.services.dbproxyd.v1.GetAccountRequest\x1a>.github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1.Account\"\x00\x12\x9b\x01\n\rCreateAccount\x12H.github.com.metaprov.modelaapi.services.dbproxyd.v1.CreateAccountRequest\x1a>.github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1.Account\"\x00\x12\x9b\x01\n\rUpdateAccount\x12H.github.com.metaprov.modelaapi.services.dbproxyd.v1.UpdateAccountRequest\x1a>.github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1.Account\"\x00\x12s\n\rDeleteAccount\x12H.github.com.metaprov.modelaapi.services.dbproxyd.v1.DeleteAccountRequest\x1a\x16.google.protobuf.Empty\"\x00\x12\x9d\x01\n\nListAlerts\x12\x45.github.com.metaprov.modelaapi.services.dbproxyd.v1.ListAlertsRequest\x1a\x46.github.com.metaprov.modelaapi.services.dbproxyd.v1.ListAlertsResponse\"\x00\x12\x8f\x01\n\x08GetAlert\x12\x43.github.com.metaprov.modelaapi.services.dbproxyd.v1.GetAlertRequest\x1a<.github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1.Alert\"\x00\x12\x95\x01\n\x0b\x43reateAlert\x12\x46.github.com.metaprov.modelaapi.services.dbproxyd.v1.CreateAlertRequest\x1a<.github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1.Alert\"\x00\x12\x95\x01\n\x0bUpdateAlert\x12\x46.github.com.metaprov.modelaapi.services.dbproxyd.v1.UpdateAlertRequest\x1a<.github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1.Alert\"\x00\x12o\n\x0b\x44\x65leteAlert\x12\x46.github.com.metaprov.modelaapi.services.dbproxyd.v1.DeleteAlertRequest\x1a\x16.google.protobuf.Empty\"\x00\x12\x9a\x01\n\tListTodos\x12\x44.github.com.metaprov.modelaapi.services.dbproxyd.v1.ListTodosRequest\x1a\x45.github.com.metaprov.modelaapi.services.dbproxyd.v1.ListTodosResponse\"\x00\x12\x8b\x01\n\x07GetTodo\x12\x42.github.com.metaprov.modelaapi.services.dbproxyd.v1.GetTodoRequest\x1a:.github.com.metaprov.modelaapi.pkg.apis.team.v1alpha1.Todo\"\x00\x12\x91\x01\n\nCreateTodo\x12\x45.github.com.metaprov.modelaapi.services.dbproxyd.v1.CreateTodoRequest\x1a:.github.com.metaprov.modelaapi.pkg.apis.team.v1alpha1.Todo\"\x00\x12\x91\x01\n\nUpdateTodo\x12\x45.github.com.metaprov.modelaapi.services.dbproxyd.v1.UpdateTodoRequest\x1a:.github.com.metaprov.modelaapi.pkg.apis.team.v1alpha1.Todo\"\x00\x12m\n\nDeleteTodo\x12\x45.github.com.metaprov.modelaapi.services.dbproxyd.v1.DeleteTodoRequest\x1a\x16.google.protobuf.Empty\"\x00\x12\xac\x01\n\x0fListAttachments\x12J.github.com.metaprov.modelaapi.services.dbproxyd.v1.ListAttachmentsRequest\x1aK.github.com.metaprov.modelaapi.services.dbproxyd.v1.ListAttachmentsResponse\"\x00\x12\x9e\x01\n\rGetAttachment\x12H.github.com.metaprov.modelaapi.services.dbproxyd.v1.GetAttachmentRequest\x1a\x41.github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1.Attachment\"\x00\x12\xa4\x01\n\x10\x43reateAttachment\x12K.github.com.metaprov.modelaapi.services.dbproxyd.v1.CreateAttachmentRequest\x1a\x41.github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1.Attachment\"\x00\x12\xa4\x01\n\x10UpdateAttachment\x12K.github.com.metaprov.modelaapi.services.dbproxyd.v1.UpdateAttachmentRequest\x1a\x41.github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1.Attachment\"\x00\x12y\n\x10\x44\x65leteAttachment\x12K.github.com.metaprov.modelaapi.services.dbproxyd.v1.DeleteAttachmentRequest\x1a\x16.google.protobuf.Empty\"\x00\x12\xac\x01\n\x0fListConnections\x12J.github.com.metaprov.modelaapi.services.dbproxyd.v1.ListConnectionsRequest\x1aK.github.com.metaprov.modelaapi.services.dbproxyd.v1.ListConnectionsResponse\"\x00\x12\x9e\x01\n\rGetConnection\x12H.github.com.metaprov.modelaapi.services.dbproxyd.v1.GetConnectionRequest\x1a\x41.github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1.Connection\"\x00\x12\xa4\x01\n\x10\x43reateConnection\x12K.github.com.metaprov.modelaapi.services.dbproxyd.v1.CreateConnectionRequest\x1a\x41.github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1.Connection\"\x00\x12\xa4\x01\n\x10UpdateConnection\x12K.github.com.metaprov.modelaapi.services.dbproxyd.v1.UpdateConnectionRequest\x1a\x41.github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1.Connection\"\x00\x12y\n\x10\x44\x65leteConnection\x12K.github.com.metaprov.modelaapi.services.dbproxyd.v1.DeleteConnectionRequest\x1a\x16.google.protobuf.Empty\"\x00\x12\x97\x01\n\x08ListLabs\x12\x43.github.com.metaprov.modelaapi.services.dbproxyd.v1.ListLabsRequest\x1a\x44.github.com.metaprov.modelaapi.services.dbproxyd.v1.ListLabsResponse\"\x00\x12\x89\x01\n\x06GetLab\x12\x41.github.com.metaprov.modelaapi.services.dbproxyd.v1.GetLabRequest\x1a:.github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1.Lab\"\x00\x12\x8f\x01\n\tCreateLab\x12\x44.github.com.metaprov.modelaapi.services.dbproxyd.v1.CreateLabRequest\x1a:.github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1.Lab\"\x00\x12\x8f\x01\n\tUpdateLab\x12\x44.github.com.metaprov.modelaapi.services.dbproxyd.v1.UpdateLabRequest\x1a:.github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1.Lab\"\x00\x12k\n\tDeleteLab\x12\x44.github.com.metaprov.modelaapi.services.dbproxyd.v1.DeleteLabRequest\x1a\x16.google.protobuf.Empty\"\x00\x12\xa3\x01\n\x0cListLicenses\x12G.github.com.metaprov.modelaapi.services.dbproxyd.v1.ListLicensesRequest\x1aH.github.com.metaprov.modelaapi.services.dbproxyd.v1.ListLicensesResponse\"\x00\x12\x95\x01\n\nGetLicense\x12\x45.github.com.metaprov.modelaapi.services.dbproxyd.v1.GetLicenseRequest\x1a>.github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1.License\"\x00\x12\x9b\x01\n\rCreateLicense\x12H.github.com.metaprov.modelaapi.services.dbproxyd.v1.CreateLicenseRequest\x1a>.github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1.License\"\x00\x12\x9b\x01\n\rUpdateLicense\x12H.github.com.metaprov.modelaapi.services.dbproxyd.v1.UpdateLicenseRequest\x1a>.github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1.License\"\x00\x12s\n\rDeleteLicense\x12H.github.com.metaprov.modelaapi.services.dbproxyd.v1.DeleteLicenseRequest\x1a\x16.google.protobuf.Empty\"\x00\x12\xa6\x01\n\rListNotifiers\x12H.github.com.metaprov.modelaapi.services.dbproxyd.v1.ListNotifiersRequest\x1aI.github.com.metaprov.modelaapi.services.dbproxyd.v1.ListNotifiersResponse\"\x00\x12\x98\x01\n\x0bGetNotifier\x12\x46.github.com.metaprov.modelaapi.services.dbproxyd.v1.GetNotifierRequest\x1a?.github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1.Notifier\"\x00\x12\x9e\x01\n\x0e\x43reateNotifier\x12I.github.com.metaprov.modelaapi.services.dbproxyd.v1.CreateNotifierRequest\x1a?.github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1.Notifier\"\x00\x12\x9e\x01\n\x0eUpdateNotifier\x12I.github.com.metaprov.modelaapi.services.dbproxyd.v1.UpdateNotifierRequest\x1a?.github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1.Notifier\"\x00\x12u\n\x0e\x44\x65leteNotifier\x12I.github.com.metaprov.modelaapi.services.dbproxyd.v1.DeleteNotifierRequest\x1a\x16.google.protobuf.Empty\"\x00\x12\xaf\x01\n\x10ListServingSites\x12K.github.com.metaprov.modelaapi.services.dbproxyd.v1.ListServingsitesRequest\x1aL.github.com.metaprov.modelaapi.services.dbproxyd.v1.ListServingsitesResponse\"\x00\x12\xa1\x01\n\x0eGetServingSite\x12I.github.com.metaprov.modelaapi.services.dbproxyd.v1.GetServingsiteRequest\x1a\x42.github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1.ServingSite\"\x00\x12\xa7\x01\n\x11\x43reateServingSite\x12L.github.com.metaprov.modelaapi.services.dbproxyd.v1.CreateServingsiteRequest\x1a\x42.github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1.ServingSite\"\x00\x12\xa7\x01\n\x11UpdateServingSite\x12L.github.com.metaprov.modelaapi.services.dbproxyd.v1.UpdateServingsiteRequest\x1a\x42.github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1.ServingSite\"\x00\x12{\n\x11\x44\x65leteServingSite\x12L.github.com.metaprov.modelaapi.services.dbproxyd.v1.DeleteServingsiteRequest\x1a\x16.google.protobuf.Empty\"\x00\x12\xa0\x01\n\x0bListTenants\x12\x46.github.com.metaprov.modelaapi.services.dbproxyd.v1.ListTenantsRequest\x1aG.github.com.metaprov.modelaapi.services.dbproxyd.v1.ListTenantsResponse\"\x00\x12\x92\x01\n\tGetTenant\x12\x44.github.com.metaprov.modelaapi.services.dbproxyd.v1.GetTenantRequest\x1a=.github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1.Tenant\"\x00\x12\x98\x01\n\x0c\x43reateTenant\x12G.github.com.metaprov.modelaapi.services.dbproxyd.v1.CreateTenantRequest\x1a=.github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1.Tenant\"\x00\x12\x98\x01\n\x0cUpdateTenant\x12G.github.com.metaprov.modelaapi.services.dbproxyd.v1.UpdateTenantRequest\x1a=.github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1.Tenant\"\x00\x12q\n\x0c\x44\x65leteTenant\x12G.github.com.metaprov.modelaapi.services.dbproxyd.v1.DeleteTenantRequest\x1a\x16.google.protobuf.Empty\"\x00\x12\xb5\x01\n\x12ListVirtualBuckets\x12M.github.com.metaprov.modelaapi.services.dbproxyd.v1.ListVirtualBucketsRequest\x1aN.github.com.metaprov.modelaapi.services.dbproxyd.v1.ListVirtualBucketsResponse\"\x00\x12\xa7\x01\n\x10GetVirtualBucket\x12K.github.com.metaprov.modelaapi.services.dbproxyd.v1.GetVirtualBucketRequest\x1a\x44.github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1.VirtualBucket\"\x00\x12\xad\x01\n\x13\x43reateVirtualBucket\x12N.github.com.metaprov.modelaapi.services.dbproxyd.v1.CreateVirtualBucketRequest\x1a\x44.github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1.VirtualBucket\"\x00\x12\xad\x01\n\x13UpdateVirtualBucket\x12N.github.com.metaprov.modelaapi.services.dbproxyd.v1.UpdateVirtualBucketRequest\x1a\x44.github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1.VirtualBucket\"\x00\x12\x7f\n\x13\x44\x65leteVirtualBucket\x12N.github.com.metaprov.modelaapi.services.dbproxyd.v1.DeleteVirtualBucketRequest\x1a\x16.google.protobuf.Empty\"\x00\x12\xb2\x01\n\x11ListDataPipelines\x12L.github.com.metaprov.modelaapi.services.dbproxyd.v1.ListDataPipelinesRequest\x1aM.github.com.metaprov.modelaapi.services.dbproxyd.v1.ListDataPipelinesResponse\"\x00\x12\xa3\x01\n\x0fGetDataPipeline\x12J.github.com.metaprov.modelaapi.services.dbproxyd.v1.GetDataPipelineRequest\x1a\x42.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.DataPipeline\"\x00\x12\xa9\x01\n\x12\x43reateDataPipeline\x12M.github.com.metaprov.modelaapi.services.dbproxyd.v1.CreateDataPipelineRequest\x1a\x42.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.DataPipeline\"\x00\x12\xa9\x01\n\x12UpdateDataPipeline\x12M.github.com.metaprov.modelaapi.services.dbproxyd.v1.UpdateDataPipelineRequest\x1a\x42.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.DataPipeline\"\x00\x12}\n\x12\x44\x65leteDataPipeline\x12M.github.com.metaprov.modelaapi.services.dbproxyd.v1.DeleteDataPipelineRequest\x1a\x16.google.protobuf.Empty\"\x00\x12\xbb\x01\n\x14ListDataPipelineRuns\x12O.github.com.metaprov.modelaapi.services.dbproxyd.v1.ListDataPipelineRunsRequest\x1aP.github.com.metaprov.modelaapi.services.dbproxyd.v1.ListDataPipelineRunsResponse\"\x00\x12\xac\x01\n\x12GetDataPipelineRun\x12M.github.com.metaprov.modelaapi.services.dbproxyd.v1.GetDataPipelineRunRequest\x1a\x45.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.DataPipelineRun\"\x00\x12\xb2\x01\n\x15\x43reateDataPipelineRun\x12P.github.com.metaprov.modelaapi.services.dbproxyd.v1.CreateDataPipelineRunRequest\x1a\x45.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.DataPipelineRun\"\x00\x12\xb2\x01\n\x15UpdateDataPipelineRun\x12P.github.com.metaprov.modelaapi.services.dbproxyd.v1.UpdateDataPipelineRunRequest\x1a\x45.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.DataPipelineRun\"\x00\x12\x83\x01\n\x15\x44\x65leteDataPipelineRun\x12P.github.com.metaprov.modelaapi.services.dbproxyd.v1.DeleteDataPipelineRunRequest\x1a\x16.google.protobuf.Empty\"\x00\x12\xaf\x01\n\x10ListDataProducts\x12K.github.com.metaprov.modelaapi.services.dbproxyd.v1.ListDataProductsRequest\x1aL.github.com.metaprov.modelaapi.services.dbproxyd.v1.ListDataProductsResponse\"\x00\x12\xa0\x01\n\x0eGetDataProduct\x12I.github.com.metaprov.modelaapi.services.dbproxyd.v1.GetDataProductRequest\x1a\x41.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.DataProduct\"\x00\x12\xa6\x01\n\x11\x43reateDataProduct\x12L.github.com.metaprov.modelaapi.services.dbproxyd.v1.CreateDataProductRequest\x1a\x41.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.DataProduct\"\x00\x12\xa6\x01\n\x11UpdateDataProduct\x12L.github.com.metaprov.modelaapi.services.dbproxyd.v1.UpdateDataProductRequest\x1a\x41.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.DataProduct\"\x00\x12{\n\x11\x44\x65leteDataProduct\x12L.github.com.metaprov.modelaapi.services.dbproxyd.v1.DeleteDataProductRequest\x1a\x16.google.protobuf.Empty\"\x00\x12\xc4\x01\n\x17ListDataProductVersions\x12R.github.com.metaprov.modelaapi.services.dbproxyd.v1.ListDataProductVersionsRequest\x1aS.github.com.metaprov.modelaapi.services.dbproxyd.v1.ListDataProductVersionsResponse\"\x00\x12\xb5\x01\n\x15GetDataProductVersion\x12P.github.com.metaprov.modelaapi.services.dbproxyd.v1.GetDataProductVersionRequest\x1aH.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.DataProductVersion\"\x00\x12\xbb\x01\n\x18\x43reateDataProductVersion\x12S.github.com.metaprov.modelaapi.services.dbproxyd.v1.CreateDataProductVersionRequest\x1aH.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.DataProductVersion\"\x00\x12\xbb\x01\n\x18UpdateDataProductVersion\x12S.github.com.metaprov.modelaapi.services.dbproxyd.v1.UpdateDataProductVersionRequest\x1aH.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.DataProductVersion\"\x00\x12\x89\x01\n\x18\x44\x65leteDataProductVersion\x12S.github.com.metaprov.modelaapi.services.dbproxyd.v1.DeleteDataProductVersionRequest\x1a\x16.google.protobuf.Empty\"\x00\x12\xa3\x01\n\x0cListDatasets\x12G.github.com.metaprov.modelaapi.services.dbproxyd.v1.ListDatasetsRequest\x1aH.github.com.metaprov.modelaapi.services.dbproxyd.v1.ListDatasetsResponse\"\x00\x12\x94\x01\n\nGetDataset\x12\x45.github.com.metaprov.modelaapi.services.dbproxyd.v1.GetDatasetRequest\x1a=.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.Dataset\"\x00\x12\x9a\x01\n\rCreateDataset\x12H.github.com.metaprov.modelaapi.services.dbproxyd.v1.CreateDatasetRequest\x1a=.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.Dataset\"\x00\x12\x9a\x01\n\rUpdateDataset\x12H.github.com.metaprov.modelaapi.services.dbproxyd.v1.UpdateDatasetRequest\x1a=.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.Dataset\"\x00\x12s\n\rDeleteDataset\x12H.github.com.metaprov.modelaapi.services.dbproxyd.v1.DeleteDatasetRequest\x1a\x16.google.protobuf.Empty\"\x00\x12\xac\x01\n\x0fListDataSources\x12J.github.com.metaprov.modelaapi.services.dbproxyd.v1.ListDatasourcesRequest\x1aK.github.com.metaprov.modelaapi.services.dbproxyd.v1.ListDatasourcesResponse\"\x00\x12\x9d\x01\n\rGetDataSource\x12H.github.com.metaprov.modelaapi.services.dbproxyd.v1.GetDatasourceRequest\x1a@.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.DataSource\"\x00\x12\xa3\x01\n\x10\x43reateDataSource\x12K.github.com.metaprov.modelaapi.services.dbproxyd.v1.CreateDatasourceRequest\x1a@.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.DataSource\"\x00\x12\xa3\x01\n\x10UpdateDataSource\x12K.github.com.metaprov.modelaapi.services.dbproxyd.v1.UpdateDatasourceRequest\x1a@.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.DataSource\"\x00\x12y\n\x10\x44\x65leteDataSource\x12K.github.com.metaprov.modelaapi.services.dbproxyd.v1.DeleteDatasourceRequest\x1a\x16.google.protobuf.Empty\"\x00\x12\xa3\x01\n\x0cListEntities\x12G.github.com.metaprov.modelaapi.services.dbproxyd.v1.ListEntitiesRequest\x1aH.github.com.metaprov.modelaapi.services.dbproxyd.v1.ListEntitiesResponse\"\x00\x12\x91\x01\n\tGetEntity\x12\x44.github.com.metaprov.modelaapi.services.dbproxyd.v1.GetEntityRequest\x1a<.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.Entity\"\x00\x12\x97\x01\n\x0c\x43reateEntity\x12G.github.com.metaprov.modelaapi.services.dbproxyd.v1.CreateEntityRequest\x1a<.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.Entity\"\x00\x12\x97\x01\n\x0cUpdateEntity\x12G.github.com.metaprov.modelaapi.services.dbproxyd.v1.UpdateEntityRequest\x1a<.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.Entity\"\x00\x12q\n\x0c\x44\x65leteEntity\x12G.github.com.metaprov.modelaapi.services.dbproxyd.v1.DeleteEntityRequest\x1a\x16.google.protobuf.Empty\"\x00\x12\xad\x01\n\x0eListModelClass\x12K.github.com.metaprov.modelaapi.services.dbproxyd.v1.ListModelClassesRequest\x1aL.github.com.metaprov.modelaapi.services.dbproxyd.v1.ListModelClassesResponse\"\x00\x12\xa1\x01\n\rGetModelClass\x12H.github.com.metaprov.modelaapi.services.dbproxyd.v1.GetModelClassRequest\x1a\x44.github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.ModelClass\"\x00\x12\xa7\x01\n\x10\x43reateModelClass\x12K.github.com.metaprov.modelaapi.services.dbproxyd.v1.CreateModelClassRequest\x1a\x44.github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.ModelClass\"\x00\x12\xa7\x01\n\x10UpdateModelClass\x12K.github.com.metaprov.modelaapi.services.dbproxyd.v1.UpdateModelClassRequest\x1a\x44.github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.ModelClass\"\x00\x12y\n\x10\x44\x65leteModelClass\x12K.github.com.metaprov.modelaapi.services.dbproxyd.v1.DeleteModelClassRequest\x1a\x16.google.protobuf.Empty\"\x00\x12\xb6\x01\n\x11ListModelClassRun\x12N.github.com.metaprov.modelaapi.services.dbproxyd.v1.ListModelClassesRunRequest\x1aO.github.com.metaprov.modelaapi.services.dbproxyd.v1.ListModelClasseRunsResponse\"\x00\x12\xaa\x01\n\x10GetModelClassRun\x12K.github.com.metaprov.modelaapi.services.dbproxyd.v1.GetModelClassRunRequest\x1aG.github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.ModelClassRun\"\x00\x12\xb0\x01\n\x13\x43reateModelClassRun\x12N.github.com.metaprov.modelaapi.services.dbproxyd.v1.CreateModelClassRunRequest\x1aG.github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.ModelClassRun\"\x00\x12\xb0\x01\n\x13UpdateModelClassRun\x12N.github.com.metaprov.modelaapi.services.dbproxyd.v1.UpdateModelClassRunRequest\x1aG.github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.ModelClassRun\"\x00\x12\x7f\n\x13\x44\x65leteModelClassRun\x12N.github.com.metaprov.modelaapi.services.dbproxyd.v1.DeleteModelClassRunRequest\x1a\x16.google.protobuf.Empty\"\x00\x12\xbe\x01\n\x15ListFeatureHistograms\x12P.github.com.metaprov.modelaapi.services.dbproxyd.v1.ListFeatureHistogramsRequest\x1aQ.github.com.metaprov.modelaapi.services.dbproxyd.v1.ListFeatureHistogramsResponse\"\x00\x12\xaf\x01\n\x13GetFeatureHistogram\x12N.github.com.metaprov.modelaapi.services.dbproxyd.v1.GetFeatureHistogramRequest\x1a\x46.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.FeatureHistogram\"\x00\x12\xb5\x01\n\x16\x43reateFeatureHistogram\x12Q.github.com.metaprov.modelaapi.services.dbproxyd.v1.CreateFeatureHistogramRequest\x1a\x46.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.FeatureHistogram\"\x00\x12\xb5\x01\n\x16UpdateFeatureHistogram\x12Q.github.com.metaprov.modelaapi.services.dbproxyd.v1.UpdateFeatureHistogramRequest\x1a\x46.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.FeatureHistogram\"\x00\x12\x85\x01\n\x16\x44\x65leteFeatureHistogram\x12Q.github.com.metaprov.modelaapi.services.dbproxyd.v1.DeleteFeatureHistogramRequest\x1a\x16.google.protobuf.Empty\"\x00\x12\xb0\x01\n\x11ListFeatureGroups\x12K.github.com.metaprov.modelaapi.services.dbproxyd.v1.ListFeatureGroupRequest\x1aL.github.com.metaprov.modelaapi.services.dbproxyd.v1.ListFeatureGroupResponse\"\x00\x12\xa3\x01\n\x0fGetFeatureGroup\x12J.github.com.metaprov.modelaapi.services.dbproxyd.v1.GetFeatureGroupRequest\x1a\x42.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.FeatureGroup\"\x00\x12\xa9\x01\n\x12\x43reateFeatureGroup\x12M.github.com.metaprov.modelaapi.services.dbproxyd.v1.CreateFeatureGroupRequest\x1a\x42.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.FeatureGroup\"\x00\x12\xa9\x01\n\x12UpdateFeatureGroup\x12M.github.com.metaprov.modelaapi.services.dbproxyd.v1.UpdateFeatureGroupRequest\x1a\x42.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.FeatureGroup\"\x00\x12}\n\x12\x44\x65leteFeatureGroup\x12M.github.com.metaprov.modelaapi.services.dbproxyd.v1.DeleteFeatureGroupRequest\x1a\x16.google.protobuf.Empty\"\x00\x12\xa0\x01\n\x0bListRecipes\x12\x46.github.com.metaprov.modelaapi.services.dbproxyd.v1.ListRecipesRequest\x1aG.github.com.metaprov.modelaapi.services.dbproxyd.v1.ListRecipesResponse\"\x00\x12\x91\x01\n\tGetRecipe\x12\x44.github.com.metaprov.modelaapi.services.dbproxyd.v1.GetRecipeRequest\x1a<.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.Recipe\"\x00\x12\x97\x01\n\x0c\x43reateRecipe\x12G.github.com.metaprov.modelaapi.services.dbproxyd.v1.CreateRecipeRequest\x1a<.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.Recipe\"\x00\x12\x97\x01\n\x0cUpdateRecipe\x12G.github.com.metaprov.modelaapi.services.dbproxyd.v1.UpdateRecipeRequest\x1a<.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.Recipe\"\x00\x12q\n\x0c\x44\x65leteRecipe\x12G.github.com.metaprov.modelaapi.services.dbproxyd.v1.DeleteRecipeRequest\x1a\x16.google.protobuf.Empty\"\x00\x12\xa9\x01\n\x0eListRecipeRuns\x12I.github.com.metaprov.modelaapi.services.dbproxyd.v1.ListRecipeRunsRequest\x1aJ.github.com.metaprov.modelaapi.services.dbproxyd.v1.ListRecipeRunsResponse\"\x00\x12\x9a\x01\n\x0cGetRecipeRun\x12G.github.com.metaprov.modelaapi.services.dbproxyd.v1.GetRecipeRunRequest\x1a?.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.RecipeRun\"\x00\x12\xa0\x01\n\x0f\x43reateRecipeRun\x12J.github.com.metaprov.modelaapi.services.dbproxyd.v1.CreateRecipeRunRequest\x1a?.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.RecipeRun\"\x00\x12\xa0\x01\n\x0fUpdateRecipeRun\x12J.github.com.metaprov.modelaapi.services.dbproxyd.v1.UpdateRecipeRunRequest\x1a?.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.RecipeRun\"\x00\x12w\n\x0f\x44\x65leteRecipeRun\x12J.github.com.metaprov.modelaapi.services.dbproxyd.v1.DeleteRecipeRunRequest\x1a\x16.google.protobuf.Empty\"\x00\x12\xa0\x01\n\x0bListReports\x12\x46.github.com.metaprov.modelaapi.services.dbproxyd.v1.ListReportsRequest\x1aG.github.com.metaprov.modelaapi.services.dbproxyd.v1.ListReportsResponse\"\x00\x12\x95\x01\n\tGetReport\x12\x44.github.com.metaprov.modelaapi.services.dbproxyd.v1.GetReportRequest\x1a@.github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.Report\"\x00\x12\x9b\x01\n\x0c\x43reateReport\x12G.github.com.metaprov.modelaapi.services.dbproxyd.v1.CreateReportRequest\x1a@.github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.Report\"\x00\x12\x9b\x01\n\x0cUpdateReport\x12G.github.com.metaprov.modelaapi.services.dbproxyd.v1.UpdateReportRequest\x1a@.github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.Report\"\x00\x12q\n\x0c\x44\x65leteReport\x12G.github.com.metaprov.modelaapi.services.dbproxyd.v1.DeleteReportRequest\x1a\x16.google.protobuf.Empty\"\x00\x12\xa0\x01\n\x0bListStudies\x12\x46.github.com.metaprov.modelaapi.services.dbproxyd.v1.ListStudiesRequest\x1aG.github.com.metaprov.modelaapi.services.dbproxyd.v1.ListStudiesResponse\"\x00\x12\x92\x01\n\x08GetStudy\x12\x43.github.com.metaprov.modelaapi.services.dbproxyd.v1.GetStudyRequest\x1a?.github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.Study\"\x00\x12\x98\x01\n\x0b\x43reateStudy\x12\x46.github.com.metaprov.modelaapi.services.dbproxyd.v1.CreateStudyRequest\x1a?.github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.Study\"\x00\x12\x98\x01\n\x0bUpdateStudy\x12\x46.github.com.metaprov.modelaapi.services.dbproxyd.v1.UpdateStudyRequest\x1a?.github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.Study\"\x00\x12o\n\x0b\x44\x65leteStudy\x12\x46.github.com.metaprov.modelaapi.services.dbproxyd.v1.DeleteStudyRequest\x1a\x16.google.protobuf.Empty\"\x00\x12\x9d\x01\n\nListModels\x12\x45.github.com.metaprov.modelaapi.services.dbproxyd.v1.ListModelsRequest\x1a\x46.github.com.metaprov.modelaapi.services.dbproxyd.v1.ListModelsResponse\"\x00\x12\x92\x01\n\x08GetModel\x12\x43.github.com.metaprov.modelaapi.services.dbproxyd.v1.GetModelRequest\x1a?.github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.Model\"\x00\x12\x98\x01\n\x0b\x43reateModel\x12\x46.github.com.metaprov.modelaapi.services.dbproxyd.v1.CreateModelRequest\x1a?.github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.Model\"\x00\x12\x98\x01\n\x0bUpdateModel\x12\x46.github.com.metaprov.modelaapi.services.dbproxyd.v1.UpdateModelRequest\x1a?.github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.Model\"\x00\x12o\n\x0b\x44\x65leteModel\x12\x46.github.com.metaprov.modelaapi.services.dbproxyd.v1.DeleteModelRequest\x1a\x16.google.protobuf.Empty\"\x00\x12\xac\x01\n\x0fListPredictions\x12J.github.com.metaprov.modelaapi.services.dbproxyd.v1.ListPredictionsRequest\x1aK.github.com.metaprov.modelaapi.services.dbproxyd.v1.ListPredictionsResponse\"\x00\x12\xa2\x01\n\rGetPrediction\x12H.github.com.metaprov.modelaapi.services.dbproxyd.v1.GetPredictionRequest\x1a\x45.github.com.metaprov.modelaapi.pkg.apis.inference.v1alpha1.Prediction\"\x00\x12\xa8\x01\n\x10\x43reatePrediction\x12K.github.com.metaprov.modelaapi.services.dbproxyd.v1.CreatePredictionRequest\x1a\x45.github.com.metaprov.modelaapi.pkg.apis.inference.v1alpha1.Prediction\"\x00\x12\xa8\x01\n\x10UpdatePrediction\x12K.github.com.metaprov.modelaapi.services.dbproxyd.v1.UpdatePredictionRequest\x1a\x45.github.com.metaprov.modelaapi.pkg.apis.inference.v1alpha1.Prediction\"\x00\x12y\n\x10\x44\x65letePrediction\x12K.github.com.metaprov.modelaapi.services.dbproxyd.v1.DeletePredictionRequest\x1a\x16.google.protobuf.Empty\"\x00\x12\xa9\x01\n\x0eListPredictors\x12I.github.com.metaprov.modelaapi.services.dbproxyd.v1.ListPredictorsRequest\x1aJ.github.com.metaprov.modelaapi.services.dbproxyd.v1.ListPredictorsResponse\"\x00\x12\x9f\x01\n\x0cGetPredictor\x12G.github.com.metaprov.modelaapi.services.dbproxyd.v1.GetPredictorRequest\x1a\x44.github.com.metaprov.modelaapi.pkg.apis.inference.v1alpha1.Predictor\"\x00\x12\xa5\x01\n\x0f\x43reatePredictor\x12J.github.com.metaprov.modelaapi.services.dbproxyd.v1.CreatePredictorRequest\x1a\x44.github.com.metaprov.modelaapi.pkg.apis.inference.v1alpha1.Predictor\"\x00\x12\xa5\x01\n\x0fUpdatePredictor\x12J.github.com.metaprov.modelaapi.services.dbproxyd.v1.UpdatePredictorRequest\x1a\x44.github.com.metaprov.modelaapi.pkg.apis.inference.v1alpha1.Predictor\"\x00\x12w\n\x0f\x44\x65letePredictor\x12J.github.com.metaprov.modelaapi.services.dbproxyd.v1.DeletePredictorRequest\x1a\x16.google.protobuf.Empty\"\x00\x12\xa0\x01\n\x0bListReviews\x12\x46.github.com.metaprov.modelaapi.services.dbproxyd.v1.ListReviewsRequest\x1aG.github.com.metaprov.modelaapi.services.dbproxyd.v1.ListReviewsResponse\"\x00\x12\x91\x01\n\tGetReview\x12\x44.github.com.metaprov.modelaapi.services.dbproxyd.v1.GetReviewRequest\x1a<.github.com.metaprov.modelaapi.pkg.apis.team.v1alpha1.Review\"\x00\x12\x97\x01\n\x0c\x43reateReview\x12G.github.com.metaprov.modelaapi.services.dbproxyd.v1.CreateReviewRequest\x1a<.github.com.metaprov.modelaapi.pkg.apis.team.v1alpha1.Review\"\x00\x12\x97\x01\n\x0cUpdateReview\x12G.github.com.metaprov.modelaapi.services.dbproxyd.v1.UpdateReviewRequest\x1a<.github.com.metaprov.modelaapi.pkg.apis.team.v1alpha1.Review\"\x00\x12q\n\x0c\x44\x65leteReview\x12G.github.com.metaprov.modelaapi.services.dbproxyd.v1.DeleteReviewRequest\x1a\x16.google.protobuf.Empty\"\x00\x12\xac\x01\n\x0fListPostMortems\x12J.github.com.metaprov.modelaapi.services.dbproxyd.v1.ListPostMortemsRequest\x1aK.github.com.metaprov.modelaapi.services.dbproxyd.v1.ListPostMortemsResponse\"\x00\x12\x9d\x01\n\rGetPostMortem\x12H.github.com.metaprov.modelaapi.services.dbproxyd.v1.GetPostMortemRequest\x1a@.github.com.metaprov.modelaapi.pkg.apis.team.v1alpha1.PostMortem\"\x00\x12\xa3\x01\n\x10\x43reatePostMortem\x12K.github.com.metaprov.modelaapi.services.dbproxyd.v1.CreatePostMortemRequest\x1a@.github.com.metaprov.modelaapi.pkg.apis.team.v1alpha1.PostMortem\"\x00\x12\xa3\x01\n\x10UpdatePostMortem\x12K.github.com.metaprov.modelaapi.services.dbproxyd.v1.UpdatePostMortemRequest\x1a@.github.com.metaprov.modelaapi.pkg.apis.team.v1alpha1.PostMortem\"\x00\x12y\n\x10\x44\x65letePostMortem\x12K.github.com.metaprov.modelaapi.services.dbproxyd.v1.DeletePostMortemRequest\x1a\x16.google.protobuf.Empty\"\x00\x12\xa3\x01\n\x0cListRunBooks\x12G.github.com.metaprov.modelaapi.services.dbproxyd.v1.ListRunbooksRequest\x1aH.github.com.metaprov.modelaapi.services.dbproxyd.v1.ListRunbooksResponse\"\x00\x12\x94\x01\n\nGetRunBook\x12\x45.github.com.metaprov.modelaapi.services.dbproxyd.v1.GetRunbookRequest\x1a=.github.com.metaprov.modelaapi.pkg.apis.team.v1alpha1.RunBook\"\x00\x12\x9a\x01\n\rCreateRunBook\x12H.github.com.metaprov.modelaapi.services.dbproxyd.v1.CreateRunbookRequest\x1a=.github.com.metaprov.modelaapi.pkg.apis.team.v1alpha1.RunBook\"\x00\x12\x9a\x01\n\rUpdateRunBook\x12H.github.com.metaprov.modelaapi.services.dbproxyd.v1.UpdateRunbookRequest\x1a=.github.com.metaprov.modelaapi.pkg.apis.team.v1alpha1.RunBook\"\x00\x12s\n\rDeleteRunBook\x12H.github.com.metaprov.modelaapi.services.dbproxyd.v1.DeleteRunbookRequest\x1a\x16.google.protobuf.Empty\"\x00\x12\xa0\x01\n\x0bListDataApp\x12\x46.github.com.metaprov.modelaapi.services.dbproxyd.v1.ListDataAppRequest\x1aG.github.com.metaprov.modelaapi.services.dbproxyd.v1.ListDataAppResponse\"\x00\x12\x99\x01\n\nGetDataApp\x12\x45.github.com.metaprov.modelaapi.services.dbproxyd.v1.GetDataAppRequest\x1a\x42.github.com.metaprov.modelaapi.pkg.apis.inference.v1alpha1.DataApp\"\x00\x12\x9f\x01\n\rCreateDataApp\x12H.github.com.metaprov.modelaapi.services.dbproxyd.v1.CreateDataAppRequest\x1a\x42.github.com.metaprov.modelaapi.pkg.apis.inference.v1alpha1.DataApp\"\x00\x12\x9f\x01\n\rUpdateDataApp\x12H.github.com.metaprov.modelaapi.services.dbproxyd.v1.UpdateDataAppRequest\x1a\x42.github.com.metaprov.modelaapi.pkg.apis.inference.v1alpha1.DataApp\"\x00\x12s\n\rDeleteDataApp\x12H.github.com.metaprov.modelaapi.services.dbproxyd.v1.DeleteDataAppRequest\x1a\x16.google.protobuf.Empty\"\x00\x42\x34Z2github.com/metaprov/modelaapi/services/dbproxyd/v1b\x06proto3')



_LISTACCOUNTSREQUEST = DESCRIPTOR.message_types_by_name['ListAccountsRequest']
_LISTACCOUNTSRESPONSE = DESCRIPTOR.message_types_by_name['ListAccountsResponse']
_GETACCOUNTREQUEST = DESCRIPTOR.message_types_by_name['GetAccountRequest']
_CREATEACCOUNTREQUEST = DESCRIPTOR.message_types_by_name['CreateAccountRequest']
_UPDATEACCOUNTREQUEST = DESCRIPTOR.message_types_by_name['UpdateAccountRequest']
_DELETEACCOUNTREQUEST = DESCRIPTOR.message_types_by_name['DeleteAccountRequest']
_LISTALERTSREQUEST = DESCRIPTOR.message_types_by_name['ListAlertsRequest']
_LISTALERTSRESPONSE = DESCRIPTOR.message_types_by_name['ListAlertsResponse']
_GETALERTREQUEST = DESCRIPTOR.message_types_by_name['GetAlertRequest']
_CREATEALERTREQUEST = DESCRIPTOR.message_types_by_name['CreateAlertRequest']
_UPDATEALERTREQUEST = DESCRIPTOR.message_types_by_name['UpdateAlertRequest']
_DELETEALERTREQUEST = DESCRIPTOR.message_types_by_name['DeleteAlertRequest']
_LISTATTACHMENTSREQUEST = DESCRIPTOR.message_types_by_name['ListAttachmentsRequest']
_LISTATTACHMENTSRESPONSE = DESCRIPTOR.message_types_by_name['ListAttachmentsResponse']
_GETATTACHMENTREQUEST = DESCRIPTOR.message_types_by_name['GetAttachmentRequest']
_CREATEATTACHMENTREQUEST = DESCRIPTOR.message_types_by_name['CreateAttachmentRequest']
_UPDATEATTACHMENTREQUEST = DESCRIPTOR.message_types_by_name['UpdateAttachmentRequest']
_DELETEATTACHMENTREQUEST = DESCRIPTOR.message_types_by_name['DeleteAttachmentRequest']
_LISTTODOSREQUEST = DESCRIPTOR.message_types_by_name['ListTodosRequest']
_LISTTODOSRESPONSE = DESCRIPTOR.message_types_by_name['ListTodosResponse']
_GETTODOREQUEST = DESCRIPTOR.message_types_by_name['GetTodoRequest']
_CREATETODOREQUEST = DESCRIPTOR.message_types_by_name['CreateTodoRequest']
_UPDATETODOREQUEST = DESCRIPTOR.message_types_by_name['UpdateTodoRequest']
_DELETETODOREQUEST = DESCRIPTOR.message_types_by_name['DeleteTodoRequest']
_LISTCONNECTIONSREQUEST = DESCRIPTOR.message_types_by_name['ListConnectionsRequest']
_LISTCONNECTIONSRESPONSE = DESCRIPTOR.message_types_by_name['ListConnectionsResponse']
_GETCONNECTIONREQUEST = DESCRIPTOR.message_types_by_name['GetConnectionRequest']
_CREATECONNECTIONREQUEST = DESCRIPTOR.message_types_by_name['CreateConnectionRequest']
_UPDATECONNECTIONREQUEST = DESCRIPTOR.message_types_by_name['UpdateConnectionRequest']
_DELETECONNECTIONREQUEST = DESCRIPTOR.message_types_by_name['DeleteConnectionRequest']
_LISTLABSREQUEST = DESCRIPTOR.message_types_by_name['ListLabsRequest']
_LISTLABSRESPONSE = DESCRIPTOR.message_types_by_name['ListLabsResponse']
_GETLABREQUEST = DESCRIPTOR.message_types_by_name['GetLabRequest']
_CREATELABREQUEST = DESCRIPTOR.message_types_by_name['CreateLabRequest']
_UPDATELABREQUEST = DESCRIPTOR.message_types_by_name['UpdateLabRequest']
_DELETELABREQUEST = DESCRIPTOR.message_types_by_name['DeleteLabRequest']
_LISTLICENSESREQUEST = DESCRIPTOR.message_types_by_name['ListLicensesRequest']
_LISTLICENSESRESPONSE = DESCRIPTOR.message_types_by_name['ListLicensesResponse']
_GETLICENSEREQUEST = DESCRIPTOR.message_types_by_name['GetLicenseRequest']
_CREATELICENSEREQUEST = DESCRIPTOR.message_types_by_name['CreateLicenseRequest']
_UPDATELICENSEREQUEST = DESCRIPTOR.message_types_by_name['UpdateLicenseRequest']
_DELETELICENSEREQUEST = DESCRIPTOR.message_types_by_name['DeleteLicenseRequest']
_LISTNOTIFIERSREQUEST = DESCRIPTOR.message_types_by_name['ListNotifiersRequest']
_LISTNOTIFIERSRESPONSE = DESCRIPTOR.message_types_by_name['ListNotifiersResponse']
_GETNOTIFIERREQUEST = DESCRIPTOR.message_types_by_name['GetNotifierRequest']
_CREATENOTIFIERREQUEST = DESCRIPTOR.message_types_by_name['CreateNotifierRequest']
_UPDATENOTIFIERREQUEST = DESCRIPTOR.message_types_by_name['UpdateNotifierRequest']
_DELETENOTIFIERREQUEST = DESCRIPTOR.message_types_by_name['DeleteNotifierRequest']
_LISTSERVINGSITESREQUEST = DESCRIPTOR.message_types_by_name['ListServingsitesRequest']
_LISTSERVINGSITESRESPONSE = DESCRIPTOR.message_types_by_name['ListServingsitesResponse']
_GETSERVINGSITEREQUEST = DESCRIPTOR.message_types_by_name['GetServingsiteRequest']
_CREATESERVINGSITEREQUEST = DESCRIPTOR.message_types_by_name['CreateServingsiteRequest']
_UPDATESERVINGSITEREQUEST = DESCRIPTOR.message_types_by_name['UpdateServingsiteRequest']
_DELETESERVINGSITEREQUEST = DESCRIPTOR.message_types_by_name['DeleteServingsiteRequest']
_LISTTENANTSREQUEST = DESCRIPTOR.message_types_by_name['ListTenantsRequest']
_LISTTENANTSRESPONSE = DESCRIPTOR.message_types_by_name['ListTenantsResponse']
_GETTENANTREQUEST = DESCRIPTOR.message_types_by_name['GetTenantRequest']
_CREATETENANTREQUEST = DESCRIPTOR.message_types_by_name['CreateTenantRequest']
_UPDATETENANTREQUEST = DESCRIPTOR.message_types_by_name['UpdateTenantRequest']
_DELETETENANTREQUEST = DESCRIPTOR.message_types_by_name['DeleteTenantRequest']
_LISTVIRTUALBUCKETSREQUEST = DESCRIPTOR.message_types_by_name['ListVirtualBucketsRequest']
_LISTVIRTUALBUCKETSRESPONSE = DESCRIPTOR.message_types_by_name['ListVirtualBucketsResponse']
_GETVIRTUALBUCKETREQUEST = DESCRIPTOR.message_types_by_name['GetVirtualBucketRequest']
_CREATEVIRTUALBUCKETREQUEST = DESCRIPTOR.message_types_by_name['CreateVirtualBucketRequest']
_UPDATEVIRTUALBUCKETREQUEST = DESCRIPTOR.message_types_by_name['UpdateVirtualBucketRequest']
_DELETEVIRTUALBUCKETREQUEST = DESCRIPTOR.message_types_by_name['DeleteVirtualBucketRequest']
_LISTDATAPIPELINESREQUEST = DESCRIPTOR.message_types_by_name['ListDataPipelinesRequest']
_LISTDATAPIPELINESRESPONSE = DESCRIPTOR.message_types_by_name['ListDataPipelinesResponse']
_GETDATAPIPELINEREQUEST = DESCRIPTOR.message_types_by_name['GetDataPipelineRequest']
_CREATEDATAPIPELINEREQUEST = DESCRIPTOR.message_types_by_name['CreateDataPipelineRequest']
_UPDATEDATAPIPELINEREQUEST = DESCRIPTOR.message_types_by_name['UpdateDataPipelineRequest']
_DELETEDATAPIPELINEREQUEST = DESCRIPTOR.message_types_by_name['DeleteDataPipelineRequest']
_LISTDATAPIPELINERUNSREQUEST = DESCRIPTOR.message_types_by_name['ListDataPipelineRunsRequest']
_LISTDATAPIPELINERUNSRESPONSE = DESCRIPTOR.message_types_by_name['ListDataPipelineRunsResponse']
_GETDATAPIPELINERUNREQUEST = DESCRIPTOR.message_types_by_name['GetDataPipelineRunRequest']
_CREATEDATAPIPELINERUNREQUEST = DESCRIPTOR.message_types_by_name['CreateDataPipelineRunRequest']
_UPDATEDATAPIPELINERUNREQUEST = DESCRIPTOR.message_types_by_name['UpdateDataPipelineRunRequest']
_DELETEDATAPIPELINERUNREQUEST = DESCRIPTOR.message_types_by_name['DeleteDataPipelineRunRequest']
_LISTDATAPRODUCTSREQUEST = DESCRIPTOR.message_types_by_name['ListDataProductsRequest']
_LISTDATAPRODUCTSRESPONSE = DESCRIPTOR.message_types_by_name['ListDataProductsResponse']
_GETDATAPRODUCTREQUEST = DESCRIPTOR.message_types_by_name['GetDataProductRequest']
_CREATEDATAPRODUCTREQUEST = DESCRIPTOR.message_types_by_name['CreateDataProductRequest']
_UPDATEDATAPRODUCTREQUEST = DESCRIPTOR.message_types_by_name['UpdateDataProductRequest']
_DELETEDATAPRODUCTREQUEST = DESCRIPTOR.message_types_by_name['DeleteDataProductRequest']
_LISTDATAPRODUCTVERSIONSREQUEST = DESCRIPTOR.message_types_by_name['ListDataProductVersionsRequest']
_LISTDATAPRODUCTVERSIONSRESPONSE = DESCRIPTOR.message_types_by_name['ListDataProductVersionsResponse']
_GETDATAPRODUCTVERSIONREQUEST = DESCRIPTOR.message_types_by_name['GetDataProductVersionRequest']
_CREATEDATAPRODUCTVERSIONREQUEST = DESCRIPTOR.message_types_by_name['CreateDataProductVersionRequest']
_UPDATEDATAPRODUCTVERSIONREQUEST = DESCRIPTOR.message_types_by_name['UpdateDataProductVersionRequest']
_DELETEDATAPRODUCTVERSIONREQUEST = DESCRIPTOR.message_types_by_name['DeleteDataProductVersionRequest']
_LISTDATASETSREQUEST = DESCRIPTOR.message_types_by_name['ListDatasetsRequest']
_LISTDATASETSRESPONSE = DESCRIPTOR.message_types_by_name['ListDatasetsResponse']
_GETDATASETREQUEST = DESCRIPTOR.message_types_by_name['GetDatasetRequest']
_CREATEDATASETREQUEST = DESCRIPTOR.message_types_by_name['CreateDatasetRequest']
_UPDATEDATASETREQUEST = DESCRIPTOR.message_types_by_name['UpdateDatasetRequest']
_DELETEDATASETREQUEST = DESCRIPTOR.message_types_by_name['DeleteDatasetRequest']
_LISTDATASOURCESREQUEST = DESCRIPTOR.message_types_by_name['ListDatasourcesRequest']
_LISTDATASOURCESRESPONSE = DESCRIPTOR.message_types_by_name['ListDatasourcesResponse']
_GETDATASOURCEREQUEST = DESCRIPTOR.message_types_by_name['GetDatasourceRequest']
_CREATEDATASOURCEREQUEST = DESCRIPTOR.message_types_by_name['CreateDatasourceRequest']
_UPDATEDATASOURCEREQUEST = DESCRIPTOR.message_types_by_name['UpdateDatasourceRequest']
_DELETEDATASOURCEREQUEST = DESCRIPTOR.message_types_by_name['DeleteDatasourceRequest']
_LISTENTITIESREQUEST = DESCRIPTOR.message_types_by_name['ListEntitiesRequest']
_LISTENTITIESRESPONSE = DESCRIPTOR.message_types_by_name['ListEntitiesResponse']
_GETENTITYREQUEST = DESCRIPTOR.message_types_by_name['GetEntityRequest']
_CREATEENTITYREQUEST = DESCRIPTOR.message_types_by_name['CreateEntityRequest']
_UPDATEENTITYREQUEST = DESCRIPTOR.message_types_by_name['UpdateEntityRequest']
_DELETEENTITYREQUEST = DESCRIPTOR.message_types_by_name['DeleteEntityRequest']
_LISTMODELCLASSESREQUEST = DESCRIPTOR.message_types_by_name['ListModelClassesRequest']
_LISTMODELCLASSESRESPONSE = DESCRIPTOR.message_types_by_name['ListModelClassesResponse']
_LISTMODELCLASSESRUNREQUEST = DESCRIPTOR.message_types_by_name['ListModelClassesRunRequest']
_LISTMODELCLASSERUNSRESPONSE = DESCRIPTOR.message_types_by_name['ListModelClasseRunsResponse']
_GETMODELCLASSREQUEST = DESCRIPTOR.message_types_by_name['GetModelClassRequest']
_CREATEMODELCLASSREQUEST = DESCRIPTOR.message_types_by_name['CreateModelClassRequest']
_UPDATEMODELCLASSREQUEST = DESCRIPTOR.message_types_by_name['UpdateModelClassRequest']
_DELETEMODELCLASSREQUEST = DESCRIPTOR.message_types_by_name['DeleteModelClassRequest']
_GETMODELCLASSRUNREQUEST = DESCRIPTOR.message_types_by_name['GetModelClassRunRequest']
_CREATEMODELCLASSRUNREQUEST = DESCRIPTOR.message_types_by_name['CreateModelClassRunRequest']
_UPDATEMODELCLASSRUNREQUEST = DESCRIPTOR.message_types_by_name['UpdateModelClassRunRequest']
_DELETEMODELCLASSRUNREQUEST = DESCRIPTOR.message_types_by_name['DeleteModelClassRunRequest']
_LISTFEATUREHISTOGRAMSREQUEST = DESCRIPTOR.message_types_by_name['ListFeatureHistogramsRequest']
_LISTFEATUREHISTOGRAMSRESPONSE = DESCRIPTOR.message_types_by_name['ListFeatureHistogramsResponse']
_GETFEATUREHISTOGRAMREQUEST = DESCRIPTOR.message_types_by_name['GetFeatureHistogramRequest']
_CREATEFEATUREHISTOGRAMREQUEST = DESCRIPTOR.message_types_by_name['CreateFeatureHistogramRequest']
_UPDATEFEATUREHISTOGRAMREQUEST = DESCRIPTOR.message_types_by_name['UpdateFeatureHistogramRequest']
_DELETEFEATUREHISTOGRAMREQUEST = DESCRIPTOR.message_types_by_name['DeleteFeatureHistogramRequest']
_LISTFEATUREGROUPREQUEST = DESCRIPTOR.message_types_by_name['ListFeatureGroupRequest']
_LISTFEATUREGROUPRESPONSE = DESCRIPTOR.message_types_by_name['ListFeatureGroupResponse']
_GETFEATUREGROUPREQUEST = DESCRIPTOR.message_types_by_name['GetFeatureGroupRequest']
_CREATEFEATUREGROUPREQUEST = DESCRIPTOR.message_types_by_name['CreateFeatureGroupRequest']
_UPDATEFEATUREGROUPREQUEST = DESCRIPTOR.message_types_by_name['UpdateFeatureGroupRequest']
_DELETEFEATUREGROUPREQUEST = DESCRIPTOR.message_types_by_name['DeleteFeatureGroupRequest']
_LISTRECIPESREQUEST = DESCRIPTOR.message_types_by_name['ListRecipesRequest']
_LISTRECIPESRESPONSE = DESCRIPTOR.message_types_by_name['ListRecipesResponse']
_GETRECIPEREQUEST = DESCRIPTOR.message_types_by_name['GetRecipeRequest']
_CREATERECIPEREQUEST = DESCRIPTOR.message_types_by_name['CreateRecipeRequest']
_UPDATERECIPEREQUEST = DESCRIPTOR.message_types_by_name['UpdateRecipeRequest']
_DELETERECIPEREQUEST = DESCRIPTOR.message_types_by_name['DeleteRecipeRequest']
_LISTRECIPERUNSREQUEST = DESCRIPTOR.message_types_by_name['ListRecipeRunsRequest']
_LISTRECIPERUNSRESPONSE = DESCRIPTOR.message_types_by_name['ListRecipeRunsResponse']
_GETRECIPERUNREQUEST = DESCRIPTOR.message_types_by_name['GetRecipeRunRequest']
_CREATERECIPERUNREQUEST = DESCRIPTOR.message_types_by_name['CreateRecipeRunRequest']
_UPDATERECIPERUNREQUEST = DESCRIPTOR.message_types_by_name['UpdateRecipeRunRequest']
_DELETERECIPERUNREQUEST = DESCRIPTOR.message_types_by_name['DeleteRecipeRunRequest']
_LISTMODELSREQUEST = DESCRIPTOR.message_types_by_name['ListModelsRequest']
_LISTMODELSRESPONSE = DESCRIPTOR.message_types_by_name['ListModelsResponse']
_GETMODELREQUEST = DESCRIPTOR.message_types_by_name['GetModelRequest']
_CREATEMODELREQUEST = DESCRIPTOR.message_types_by_name['CreateModelRequest']
_UPDATEMODELREQUEST = DESCRIPTOR.message_types_by_name['UpdateModelRequest']
_DELETEMODELREQUEST = DESCRIPTOR.message_types_by_name['DeleteModelRequest']
_LISTREPORTSREQUEST = DESCRIPTOR.message_types_by_name['ListReportsRequest']
_LISTREPORTSRESPONSE = DESCRIPTOR.message_types_by_name['ListReportsResponse']
_GETREPORTREQUEST = DESCRIPTOR.message_types_by_name['GetReportRequest']
_CREATEREPORTREQUEST = DESCRIPTOR.message_types_by_name['CreateReportRequest']
_UPDATEREPORTREQUEST = DESCRIPTOR.message_types_by_name['UpdateReportRequest']
_DELETEREPORTREQUEST = DESCRIPTOR.message_types_by_name['DeleteReportRequest']
_LISTSTUDIESREQUEST = DESCRIPTOR.message_types_by_name['ListStudiesRequest']
_LISTSTUDIESRESPONSE = DESCRIPTOR.message_types_by_name['ListStudiesResponse']
_GETSTUDYREQUEST = DESCRIPTOR.message_types_by_name['GetStudyRequest']
_CREATESTUDYREQUEST = DESCRIPTOR.message_types_by_name['CreateStudyRequest']
_UPDATESTUDYREQUEST = DESCRIPTOR.message_types_by_name['UpdateStudyRequest']
_DELETESTUDYREQUEST = DESCRIPTOR.message_types_by_name['DeleteStudyRequest']
_LISTPREDICTIONSREQUEST = DESCRIPTOR.message_types_by_name['ListPredictionsRequest']
_LISTPREDICTIONSRESPONSE = DESCRIPTOR.message_types_by_name['ListPredictionsResponse']
_GETPREDICTIONREQUEST = DESCRIPTOR.message_types_by_name['GetPredictionRequest']
_CREATEPREDICTIONREQUEST = DESCRIPTOR.message_types_by_name['CreatePredictionRequest']
_UPDATEPREDICTIONREQUEST = DESCRIPTOR.message_types_by_name['UpdatePredictionRequest']
_DELETEPREDICTIONREQUEST = DESCRIPTOR.message_types_by_name['DeletePredictionRequest']
_LISTPREDICTORSREQUEST = DESCRIPTOR.message_types_by_name['ListPredictorsRequest']
_LISTPREDICTORSRESPONSE = DESCRIPTOR.message_types_by_name['ListPredictorsResponse']
_GETPREDICTORREQUEST = DESCRIPTOR.message_types_by_name['GetPredictorRequest']
_CREATEPREDICTORREQUEST = DESCRIPTOR.message_types_by_name['CreatePredictorRequest']
_UPDATEPREDICTORREQUEST = DESCRIPTOR.message_types_by_name['UpdatePredictorRequest']
_DELETEPREDICTORREQUEST = DESCRIPTOR.message_types_by_name['DeletePredictorRequest']
_LISTREVIEWSREQUEST = DESCRIPTOR.message_types_by_name['ListReviewsRequest']
_LISTREVIEWSRESPONSE = DESCRIPTOR.message_types_by_name['ListReviewsResponse']
_GETREVIEWREQUEST = DESCRIPTOR.message_types_by_name['GetReviewRequest']
_CREATEREVIEWREQUEST = DESCRIPTOR.message_types_by_name['CreateReviewRequest']
_UPDATEREVIEWREQUEST = DESCRIPTOR.message_types_by_name['UpdateReviewRequest']
_DELETEREVIEWREQUEST = DESCRIPTOR.message_types_by_name['DeleteReviewRequest']
_LISTPOSTMORTEMSREQUEST = DESCRIPTOR.message_types_by_name['ListPostMortemsRequest']
_LISTPOSTMORTEMSRESPONSE = DESCRIPTOR.message_types_by_name['ListPostMortemsResponse']
_GETPOSTMORTEMREQUEST = DESCRIPTOR.message_types_by_name['GetPostMortemRequest']
_CREATEPOSTMORTEMREQUEST = DESCRIPTOR.message_types_by_name['CreatePostMortemRequest']
_UPDATEPOSTMORTEMREQUEST = DESCRIPTOR.message_types_by_name['UpdatePostMortemRequest']
_DELETEPOSTMORTEMREQUEST = DESCRIPTOR.message_types_by_name['DeletePostMortemRequest']
_LISTRUNBOOKSREQUEST = DESCRIPTOR.message_types_by_name['ListRunbooksRequest']
_LISTRUNBOOKSRESPONSE = DESCRIPTOR.message_types_by_name['ListRunbooksResponse']
_GETRUNBOOKREQUEST = DESCRIPTOR.message_types_by_name['GetRunbookRequest']
_CREATERUNBOOKREQUEST = DESCRIPTOR.message_types_by_name['CreateRunbookRequest']
_UPDATERUNBOOKREQUEST = DESCRIPTOR.message_types_by_name['UpdateRunbookRequest']
_DELETERUNBOOKREQUEST = DESCRIPTOR.message_types_by_name['DeleteRunbookRequest']
_LISTDATAAPPREQUEST = DESCRIPTOR.message_types_by_name['ListDataAppRequest']
_LISTDATAAPPRESPONSE = DESCRIPTOR.message_types_by_name['ListDataAppResponse']
_GETDATAAPPREQUEST = DESCRIPTOR.message_types_by_name['GetDataAppRequest']
_CREATEDATAAPPREQUEST = DESCRIPTOR.message_types_by_name['CreateDataAppRequest']
_UPDATEDATAAPPREQUEST = DESCRIPTOR.message_types_by_name['UpdateDataAppRequest']
_DELETEDATAAPPREQUEST = DESCRIPTOR.message_types_by_name['DeleteDataAppRequest']
ListAccountsRequest = _reflection.GeneratedProtocolMessageType('ListAccountsRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTACCOUNTSREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.ListAccountsRequest)
  })
_sym_db.RegisterMessage(ListAccountsRequest)

ListAccountsResponse = _reflection.GeneratedProtocolMessageType('ListAccountsResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTACCOUNTSRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.ListAccountsResponse)
  })
_sym_db.RegisterMessage(ListAccountsResponse)

GetAccountRequest = _reflection.GeneratedProtocolMessageType('GetAccountRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETACCOUNTREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.GetAccountRequest)
  })
_sym_db.RegisterMessage(GetAccountRequest)

CreateAccountRequest = _reflection.GeneratedProtocolMessageType('CreateAccountRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATEACCOUNTREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.CreateAccountRequest)
  })
_sym_db.RegisterMessage(CreateAccountRequest)

UpdateAccountRequest = _reflection.GeneratedProtocolMessageType('UpdateAccountRequest', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEACCOUNTREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.UpdateAccountRequest)
  })
_sym_db.RegisterMessage(UpdateAccountRequest)

DeleteAccountRequest = _reflection.GeneratedProtocolMessageType('DeleteAccountRequest', (_message.Message,), {
  'DESCRIPTOR' : _DELETEACCOUNTREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.DeleteAccountRequest)
  })
_sym_db.RegisterMessage(DeleteAccountRequest)

ListAlertsRequest = _reflection.GeneratedProtocolMessageType('ListAlertsRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTALERTSREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.ListAlertsRequest)
  })
_sym_db.RegisterMessage(ListAlertsRequest)

ListAlertsResponse = _reflection.GeneratedProtocolMessageType('ListAlertsResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTALERTSRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.ListAlertsResponse)
  })
_sym_db.RegisterMessage(ListAlertsResponse)

GetAlertRequest = _reflection.GeneratedProtocolMessageType('GetAlertRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETALERTREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.GetAlertRequest)
  })
_sym_db.RegisterMessage(GetAlertRequest)

CreateAlertRequest = _reflection.GeneratedProtocolMessageType('CreateAlertRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATEALERTREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.CreateAlertRequest)
  })
_sym_db.RegisterMessage(CreateAlertRequest)

UpdateAlertRequest = _reflection.GeneratedProtocolMessageType('UpdateAlertRequest', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEALERTREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.UpdateAlertRequest)
  })
_sym_db.RegisterMessage(UpdateAlertRequest)

DeleteAlertRequest = _reflection.GeneratedProtocolMessageType('DeleteAlertRequest', (_message.Message,), {
  'DESCRIPTOR' : _DELETEALERTREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.DeleteAlertRequest)
  })
_sym_db.RegisterMessage(DeleteAlertRequest)

ListAttachmentsRequest = _reflection.GeneratedProtocolMessageType('ListAttachmentsRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTATTACHMENTSREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.ListAttachmentsRequest)
  })
_sym_db.RegisterMessage(ListAttachmentsRequest)

ListAttachmentsResponse = _reflection.GeneratedProtocolMessageType('ListAttachmentsResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTATTACHMENTSRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.ListAttachmentsResponse)
  })
_sym_db.RegisterMessage(ListAttachmentsResponse)

GetAttachmentRequest = _reflection.GeneratedProtocolMessageType('GetAttachmentRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETATTACHMENTREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.GetAttachmentRequest)
  })
_sym_db.RegisterMessage(GetAttachmentRequest)

CreateAttachmentRequest = _reflection.GeneratedProtocolMessageType('CreateAttachmentRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATEATTACHMENTREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.CreateAttachmentRequest)
  })
_sym_db.RegisterMessage(CreateAttachmentRequest)

UpdateAttachmentRequest = _reflection.GeneratedProtocolMessageType('UpdateAttachmentRequest', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEATTACHMENTREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.UpdateAttachmentRequest)
  })
_sym_db.RegisterMessage(UpdateAttachmentRequest)

DeleteAttachmentRequest = _reflection.GeneratedProtocolMessageType('DeleteAttachmentRequest', (_message.Message,), {
  'DESCRIPTOR' : _DELETEATTACHMENTREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.DeleteAttachmentRequest)
  })
_sym_db.RegisterMessage(DeleteAttachmentRequest)

ListTodosRequest = _reflection.GeneratedProtocolMessageType('ListTodosRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTTODOSREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.ListTodosRequest)
  })
_sym_db.RegisterMessage(ListTodosRequest)

ListTodosResponse = _reflection.GeneratedProtocolMessageType('ListTodosResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTTODOSRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.ListTodosResponse)
  })
_sym_db.RegisterMessage(ListTodosResponse)

GetTodoRequest = _reflection.GeneratedProtocolMessageType('GetTodoRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETTODOREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.GetTodoRequest)
  })
_sym_db.RegisterMessage(GetTodoRequest)

CreateTodoRequest = _reflection.GeneratedProtocolMessageType('CreateTodoRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATETODOREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.CreateTodoRequest)
  })
_sym_db.RegisterMessage(CreateTodoRequest)

UpdateTodoRequest = _reflection.GeneratedProtocolMessageType('UpdateTodoRequest', (_message.Message,), {
  'DESCRIPTOR' : _UPDATETODOREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.UpdateTodoRequest)
  })
_sym_db.RegisterMessage(UpdateTodoRequest)

DeleteTodoRequest = _reflection.GeneratedProtocolMessageType('DeleteTodoRequest', (_message.Message,), {
  'DESCRIPTOR' : _DELETETODOREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.DeleteTodoRequest)
  })
_sym_db.RegisterMessage(DeleteTodoRequest)

ListConnectionsRequest = _reflection.GeneratedProtocolMessageType('ListConnectionsRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTCONNECTIONSREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.ListConnectionsRequest)
  })
_sym_db.RegisterMessage(ListConnectionsRequest)

ListConnectionsResponse = _reflection.GeneratedProtocolMessageType('ListConnectionsResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTCONNECTIONSRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.ListConnectionsResponse)
  })
_sym_db.RegisterMessage(ListConnectionsResponse)

GetConnectionRequest = _reflection.GeneratedProtocolMessageType('GetConnectionRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETCONNECTIONREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.GetConnectionRequest)
  })
_sym_db.RegisterMessage(GetConnectionRequest)

CreateConnectionRequest = _reflection.GeneratedProtocolMessageType('CreateConnectionRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATECONNECTIONREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.CreateConnectionRequest)
  })
_sym_db.RegisterMessage(CreateConnectionRequest)

UpdateConnectionRequest = _reflection.GeneratedProtocolMessageType('UpdateConnectionRequest', (_message.Message,), {
  'DESCRIPTOR' : _UPDATECONNECTIONREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.UpdateConnectionRequest)
  })
_sym_db.RegisterMessage(UpdateConnectionRequest)

DeleteConnectionRequest = _reflection.GeneratedProtocolMessageType('DeleteConnectionRequest', (_message.Message,), {
  'DESCRIPTOR' : _DELETECONNECTIONREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.DeleteConnectionRequest)
  })
_sym_db.RegisterMessage(DeleteConnectionRequest)

ListLabsRequest = _reflection.GeneratedProtocolMessageType('ListLabsRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTLABSREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.ListLabsRequest)
  })
_sym_db.RegisterMessage(ListLabsRequest)

ListLabsResponse = _reflection.GeneratedProtocolMessageType('ListLabsResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTLABSRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.ListLabsResponse)
  })
_sym_db.RegisterMessage(ListLabsResponse)

GetLabRequest = _reflection.GeneratedProtocolMessageType('GetLabRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETLABREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.GetLabRequest)
  })
_sym_db.RegisterMessage(GetLabRequest)

CreateLabRequest = _reflection.GeneratedProtocolMessageType('CreateLabRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATELABREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.CreateLabRequest)
  })
_sym_db.RegisterMessage(CreateLabRequest)

UpdateLabRequest = _reflection.GeneratedProtocolMessageType('UpdateLabRequest', (_message.Message,), {
  'DESCRIPTOR' : _UPDATELABREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.UpdateLabRequest)
  })
_sym_db.RegisterMessage(UpdateLabRequest)

DeleteLabRequest = _reflection.GeneratedProtocolMessageType('DeleteLabRequest', (_message.Message,), {
  'DESCRIPTOR' : _DELETELABREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.DeleteLabRequest)
  })
_sym_db.RegisterMessage(DeleteLabRequest)

ListLicensesRequest = _reflection.GeneratedProtocolMessageType('ListLicensesRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTLICENSESREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.ListLicensesRequest)
  })
_sym_db.RegisterMessage(ListLicensesRequest)

ListLicensesResponse = _reflection.GeneratedProtocolMessageType('ListLicensesResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTLICENSESRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.ListLicensesResponse)
  })
_sym_db.RegisterMessage(ListLicensesResponse)

GetLicenseRequest = _reflection.GeneratedProtocolMessageType('GetLicenseRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETLICENSEREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.GetLicenseRequest)
  })
_sym_db.RegisterMessage(GetLicenseRequest)

CreateLicenseRequest = _reflection.GeneratedProtocolMessageType('CreateLicenseRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATELICENSEREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.CreateLicenseRequest)
  })
_sym_db.RegisterMessage(CreateLicenseRequest)

UpdateLicenseRequest = _reflection.GeneratedProtocolMessageType('UpdateLicenseRequest', (_message.Message,), {
  'DESCRIPTOR' : _UPDATELICENSEREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.UpdateLicenseRequest)
  })
_sym_db.RegisterMessage(UpdateLicenseRequest)

DeleteLicenseRequest = _reflection.GeneratedProtocolMessageType('DeleteLicenseRequest', (_message.Message,), {
  'DESCRIPTOR' : _DELETELICENSEREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.DeleteLicenseRequest)
  })
_sym_db.RegisterMessage(DeleteLicenseRequest)

ListNotifiersRequest = _reflection.GeneratedProtocolMessageType('ListNotifiersRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTNOTIFIERSREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.ListNotifiersRequest)
  })
_sym_db.RegisterMessage(ListNotifiersRequest)

ListNotifiersResponse = _reflection.GeneratedProtocolMessageType('ListNotifiersResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTNOTIFIERSRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.ListNotifiersResponse)
  })
_sym_db.RegisterMessage(ListNotifiersResponse)

GetNotifierRequest = _reflection.GeneratedProtocolMessageType('GetNotifierRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETNOTIFIERREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.GetNotifierRequest)
  })
_sym_db.RegisterMessage(GetNotifierRequest)

CreateNotifierRequest = _reflection.GeneratedProtocolMessageType('CreateNotifierRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATENOTIFIERREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.CreateNotifierRequest)
  })
_sym_db.RegisterMessage(CreateNotifierRequest)

UpdateNotifierRequest = _reflection.GeneratedProtocolMessageType('UpdateNotifierRequest', (_message.Message,), {
  'DESCRIPTOR' : _UPDATENOTIFIERREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.UpdateNotifierRequest)
  })
_sym_db.RegisterMessage(UpdateNotifierRequest)

DeleteNotifierRequest = _reflection.GeneratedProtocolMessageType('DeleteNotifierRequest', (_message.Message,), {
  'DESCRIPTOR' : _DELETENOTIFIERREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.DeleteNotifierRequest)
  })
_sym_db.RegisterMessage(DeleteNotifierRequest)

ListServingsitesRequest = _reflection.GeneratedProtocolMessageType('ListServingsitesRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTSERVINGSITESREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.ListServingsitesRequest)
  })
_sym_db.RegisterMessage(ListServingsitesRequest)

ListServingsitesResponse = _reflection.GeneratedProtocolMessageType('ListServingsitesResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTSERVINGSITESRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.ListServingsitesResponse)
  })
_sym_db.RegisterMessage(ListServingsitesResponse)

GetServingsiteRequest = _reflection.GeneratedProtocolMessageType('GetServingsiteRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETSERVINGSITEREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.GetServingsiteRequest)
  })
_sym_db.RegisterMessage(GetServingsiteRequest)

CreateServingsiteRequest = _reflection.GeneratedProtocolMessageType('CreateServingsiteRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATESERVINGSITEREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.CreateServingsiteRequest)
  })
_sym_db.RegisterMessage(CreateServingsiteRequest)

UpdateServingsiteRequest = _reflection.GeneratedProtocolMessageType('UpdateServingsiteRequest', (_message.Message,), {
  'DESCRIPTOR' : _UPDATESERVINGSITEREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.UpdateServingsiteRequest)
  })
_sym_db.RegisterMessage(UpdateServingsiteRequest)

DeleteServingsiteRequest = _reflection.GeneratedProtocolMessageType('DeleteServingsiteRequest', (_message.Message,), {
  'DESCRIPTOR' : _DELETESERVINGSITEREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.DeleteServingsiteRequest)
  })
_sym_db.RegisterMessage(DeleteServingsiteRequest)

ListTenantsRequest = _reflection.GeneratedProtocolMessageType('ListTenantsRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTTENANTSREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.ListTenantsRequest)
  })
_sym_db.RegisterMessage(ListTenantsRequest)

ListTenantsResponse = _reflection.GeneratedProtocolMessageType('ListTenantsResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTTENANTSRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.ListTenantsResponse)
  })
_sym_db.RegisterMessage(ListTenantsResponse)

GetTenantRequest = _reflection.GeneratedProtocolMessageType('GetTenantRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETTENANTREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.GetTenantRequest)
  })
_sym_db.RegisterMessage(GetTenantRequest)

CreateTenantRequest = _reflection.GeneratedProtocolMessageType('CreateTenantRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATETENANTREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.CreateTenantRequest)
  })
_sym_db.RegisterMessage(CreateTenantRequest)

UpdateTenantRequest = _reflection.GeneratedProtocolMessageType('UpdateTenantRequest', (_message.Message,), {
  'DESCRIPTOR' : _UPDATETENANTREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.UpdateTenantRequest)
  })
_sym_db.RegisterMessage(UpdateTenantRequest)

DeleteTenantRequest = _reflection.GeneratedProtocolMessageType('DeleteTenantRequest', (_message.Message,), {
  'DESCRIPTOR' : _DELETETENANTREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.DeleteTenantRequest)
  })
_sym_db.RegisterMessage(DeleteTenantRequest)

ListVirtualBucketsRequest = _reflection.GeneratedProtocolMessageType('ListVirtualBucketsRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTVIRTUALBUCKETSREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.ListVirtualBucketsRequest)
  })
_sym_db.RegisterMessage(ListVirtualBucketsRequest)

ListVirtualBucketsResponse = _reflection.GeneratedProtocolMessageType('ListVirtualBucketsResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTVIRTUALBUCKETSRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.ListVirtualBucketsResponse)
  })
_sym_db.RegisterMessage(ListVirtualBucketsResponse)

GetVirtualBucketRequest = _reflection.GeneratedProtocolMessageType('GetVirtualBucketRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETVIRTUALBUCKETREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.GetVirtualBucketRequest)
  })
_sym_db.RegisterMessage(GetVirtualBucketRequest)

CreateVirtualBucketRequest = _reflection.GeneratedProtocolMessageType('CreateVirtualBucketRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATEVIRTUALBUCKETREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.CreateVirtualBucketRequest)
  })
_sym_db.RegisterMessage(CreateVirtualBucketRequest)

UpdateVirtualBucketRequest = _reflection.GeneratedProtocolMessageType('UpdateVirtualBucketRequest', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEVIRTUALBUCKETREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.UpdateVirtualBucketRequest)
  })
_sym_db.RegisterMessage(UpdateVirtualBucketRequest)

DeleteVirtualBucketRequest = _reflection.GeneratedProtocolMessageType('DeleteVirtualBucketRequest', (_message.Message,), {
  'DESCRIPTOR' : _DELETEVIRTUALBUCKETREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.DeleteVirtualBucketRequest)
  })
_sym_db.RegisterMessage(DeleteVirtualBucketRequest)

ListDataPipelinesRequest = _reflection.GeneratedProtocolMessageType('ListDataPipelinesRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTDATAPIPELINESREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.ListDataPipelinesRequest)
  })
_sym_db.RegisterMessage(ListDataPipelinesRequest)

ListDataPipelinesResponse = _reflection.GeneratedProtocolMessageType('ListDataPipelinesResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTDATAPIPELINESRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.ListDataPipelinesResponse)
  })
_sym_db.RegisterMessage(ListDataPipelinesResponse)

GetDataPipelineRequest = _reflection.GeneratedProtocolMessageType('GetDataPipelineRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETDATAPIPELINEREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.GetDataPipelineRequest)
  })
_sym_db.RegisterMessage(GetDataPipelineRequest)

CreateDataPipelineRequest = _reflection.GeneratedProtocolMessageType('CreateDataPipelineRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATEDATAPIPELINEREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.CreateDataPipelineRequest)
  })
_sym_db.RegisterMessage(CreateDataPipelineRequest)

UpdateDataPipelineRequest = _reflection.GeneratedProtocolMessageType('UpdateDataPipelineRequest', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEDATAPIPELINEREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.UpdateDataPipelineRequest)
  })
_sym_db.RegisterMessage(UpdateDataPipelineRequest)

DeleteDataPipelineRequest = _reflection.GeneratedProtocolMessageType('DeleteDataPipelineRequest', (_message.Message,), {
  'DESCRIPTOR' : _DELETEDATAPIPELINEREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.DeleteDataPipelineRequest)
  })
_sym_db.RegisterMessage(DeleteDataPipelineRequest)

ListDataPipelineRunsRequest = _reflection.GeneratedProtocolMessageType('ListDataPipelineRunsRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTDATAPIPELINERUNSREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.ListDataPipelineRunsRequest)
  })
_sym_db.RegisterMessage(ListDataPipelineRunsRequest)

ListDataPipelineRunsResponse = _reflection.GeneratedProtocolMessageType('ListDataPipelineRunsResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTDATAPIPELINERUNSRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.ListDataPipelineRunsResponse)
  })
_sym_db.RegisterMessage(ListDataPipelineRunsResponse)

GetDataPipelineRunRequest = _reflection.GeneratedProtocolMessageType('GetDataPipelineRunRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETDATAPIPELINERUNREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.GetDataPipelineRunRequest)
  })
_sym_db.RegisterMessage(GetDataPipelineRunRequest)

CreateDataPipelineRunRequest = _reflection.GeneratedProtocolMessageType('CreateDataPipelineRunRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATEDATAPIPELINERUNREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.CreateDataPipelineRunRequest)
  })
_sym_db.RegisterMessage(CreateDataPipelineRunRequest)

UpdateDataPipelineRunRequest = _reflection.GeneratedProtocolMessageType('UpdateDataPipelineRunRequest', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEDATAPIPELINERUNREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.UpdateDataPipelineRunRequest)
  })
_sym_db.RegisterMessage(UpdateDataPipelineRunRequest)

DeleteDataPipelineRunRequest = _reflection.GeneratedProtocolMessageType('DeleteDataPipelineRunRequest', (_message.Message,), {
  'DESCRIPTOR' : _DELETEDATAPIPELINERUNREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.DeleteDataPipelineRunRequest)
  })
_sym_db.RegisterMessage(DeleteDataPipelineRunRequest)

ListDataProductsRequest = _reflection.GeneratedProtocolMessageType('ListDataProductsRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTDATAPRODUCTSREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.ListDataProductsRequest)
  })
_sym_db.RegisterMessage(ListDataProductsRequest)

ListDataProductsResponse = _reflection.GeneratedProtocolMessageType('ListDataProductsResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTDATAPRODUCTSRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.ListDataProductsResponse)
  })
_sym_db.RegisterMessage(ListDataProductsResponse)

GetDataProductRequest = _reflection.GeneratedProtocolMessageType('GetDataProductRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETDATAPRODUCTREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.GetDataProductRequest)
  })
_sym_db.RegisterMessage(GetDataProductRequest)

CreateDataProductRequest = _reflection.GeneratedProtocolMessageType('CreateDataProductRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATEDATAPRODUCTREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.CreateDataProductRequest)
  })
_sym_db.RegisterMessage(CreateDataProductRequest)

UpdateDataProductRequest = _reflection.GeneratedProtocolMessageType('UpdateDataProductRequest', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEDATAPRODUCTREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.UpdateDataProductRequest)
  })
_sym_db.RegisterMessage(UpdateDataProductRequest)

DeleteDataProductRequest = _reflection.GeneratedProtocolMessageType('DeleteDataProductRequest', (_message.Message,), {
  'DESCRIPTOR' : _DELETEDATAPRODUCTREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.DeleteDataProductRequest)
  })
_sym_db.RegisterMessage(DeleteDataProductRequest)

ListDataProductVersionsRequest = _reflection.GeneratedProtocolMessageType('ListDataProductVersionsRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTDATAPRODUCTVERSIONSREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.ListDataProductVersionsRequest)
  })
_sym_db.RegisterMessage(ListDataProductVersionsRequest)

ListDataProductVersionsResponse = _reflection.GeneratedProtocolMessageType('ListDataProductVersionsResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTDATAPRODUCTVERSIONSRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.ListDataProductVersionsResponse)
  })
_sym_db.RegisterMessage(ListDataProductVersionsResponse)

GetDataProductVersionRequest = _reflection.GeneratedProtocolMessageType('GetDataProductVersionRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETDATAPRODUCTVERSIONREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.GetDataProductVersionRequest)
  })
_sym_db.RegisterMessage(GetDataProductVersionRequest)

CreateDataProductVersionRequest = _reflection.GeneratedProtocolMessageType('CreateDataProductVersionRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATEDATAPRODUCTVERSIONREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.CreateDataProductVersionRequest)
  })
_sym_db.RegisterMessage(CreateDataProductVersionRequest)

UpdateDataProductVersionRequest = _reflection.GeneratedProtocolMessageType('UpdateDataProductVersionRequest', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEDATAPRODUCTVERSIONREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.UpdateDataProductVersionRequest)
  })
_sym_db.RegisterMessage(UpdateDataProductVersionRequest)

DeleteDataProductVersionRequest = _reflection.GeneratedProtocolMessageType('DeleteDataProductVersionRequest', (_message.Message,), {
  'DESCRIPTOR' : _DELETEDATAPRODUCTVERSIONREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.DeleteDataProductVersionRequest)
  })
_sym_db.RegisterMessage(DeleteDataProductVersionRequest)

ListDatasetsRequest = _reflection.GeneratedProtocolMessageType('ListDatasetsRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTDATASETSREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.ListDatasetsRequest)
  })
_sym_db.RegisterMessage(ListDatasetsRequest)

ListDatasetsResponse = _reflection.GeneratedProtocolMessageType('ListDatasetsResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTDATASETSRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.ListDatasetsResponse)
  })
_sym_db.RegisterMessage(ListDatasetsResponse)

GetDatasetRequest = _reflection.GeneratedProtocolMessageType('GetDatasetRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETDATASETREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.GetDatasetRequest)
  })
_sym_db.RegisterMessage(GetDatasetRequest)

CreateDatasetRequest = _reflection.GeneratedProtocolMessageType('CreateDatasetRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATEDATASETREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.CreateDatasetRequest)
  })
_sym_db.RegisterMessage(CreateDatasetRequest)

UpdateDatasetRequest = _reflection.GeneratedProtocolMessageType('UpdateDatasetRequest', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEDATASETREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.UpdateDatasetRequest)
  })
_sym_db.RegisterMessage(UpdateDatasetRequest)

DeleteDatasetRequest = _reflection.GeneratedProtocolMessageType('DeleteDatasetRequest', (_message.Message,), {
  'DESCRIPTOR' : _DELETEDATASETREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.DeleteDatasetRequest)
  })
_sym_db.RegisterMessage(DeleteDatasetRequest)

ListDatasourcesRequest = _reflection.GeneratedProtocolMessageType('ListDatasourcesRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTDATASOURCESREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.ListDatasourcesRequest)
  })
_sym_db.RegisterMessage(ListDatasourcesRequest)

ListDatasourcesResponse = _reflection.GeneratedProtocolMessageType('ListDatasourcesResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTDATASOURCESRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.ListDatasourcesResponse)
  })
_sym_db.RegisterMessage(ListDatasourcesResponse)

GetDatasourceRequest = _reflection.GeneratedProtocolMessageType('GetDatasourceRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETDATASOURCEREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.GetDatasourceRequest)
  })
_sym_db.RegisterMessage(GetDatasourceRequest)

CreateDatasourceRequest = _reflection.GeneratedProtocolMessageType('CreateDatasourceRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATEDATASOURCEREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.CreateDatasourceRequest)
  })
_sym_db.RegisterMessage(CreateDatasourceRequest)

UpdateDatasourceRequest = _reflection.GeneratedProtocolMessageType('UpdateDatasourceRequest', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEDATASOURCEREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.UpdateDatasourceRequest)
  })
_sym_db.RegisterMessage(UpdateDatasourceRequest)

DeleteDatasourceRequest = _reflection.GeneratedProtocolMessageType('DeleteDatasourceRequest', (_message.Message,), {
  'DESCRIPTOR' : _DELETEDATASOURCEREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.DeleteDatasourceRequest)
  })
_sym_db.RegisterMessage(DeleteDatasourceRequest)

ListEntitiesRequest = _reflection.GeneratedProtocolMessageType('ListEntitiesRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTENTITIESREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.ListEntitiesRequest)
  })
_sym_db.RegisterMessage(ListEntitiesRequest)

ListEntitiesResponse = _reflection.GeneratedProtocolMessageType('ListEntitiesResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTENTITIESRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.ListEntitiesResponse)
  })
_sym_db.RegisterMessage(ListEntitiesResponse)

GetEntityRequest = _reflection.GeneratedProtocolMessageType('GetEntityRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETENTITYREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.GetEntityRequest)
  })
_sym_db.RegisterMessage(GetEntityRequest)

CreateEntityRequest = _reflection.GeneratedProtocolMessageType('CreateEntityRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATEENTITYREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.CreateEntityRequest)
  })
_sym_db.RegisterMessage(CreateEntityRequest)

UpdateEntityRequest = _reflection.GeneratedProtocolMessageType('UpdateEntityRequest', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEENTITYREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.UpdateEntityRequest)
  })
_sym_db.RegisterMessage(UpdateEntityRequest)

DeleteEntityRequest = _reflection.GeneratedProtocolMessageType('DeleteEntityRequest', (_message.Message,), {
  'DESCRIPTOR' : _DELETEENTITYREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.DeleteEntityRequest)
  })
_sym_db.RegisterMessage(DeleteEntityRequest)

ListModelClassesRequest = _reflection.GeneratedProtocolMessageType('ListModelClassesRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTMODELCLASSESREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.ListModelClassesRequest)
  })
_sym_db.RegisterMessage(ListModelClassesRequest)

ListModelClassesResponse = _reflection.GeneratedProtocolMessageType('ListModelClassesResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTMODELCLASSESRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.ListModelClassesResponse)
  })
_sym_db.RegisterMessage(ListModelClassesResponse)

ListModelClassesRunRequest = _reflection.GeneratedProtocolMessageType('ListModelClassesRunRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTMODELCLASSESRUNREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.ListModelClassesRunRequest)
  })
_sym_db.RegisterMessage(ListModelClassesRunRequest)

ListModelClasseRunsResponse = _reflection.GeneratedProtocolMessageType('ListModelClasseRunsResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTMODELCLASSERUNSRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.ListModelClasseRunsResponse)
  })
_sym_db.RegisterMessage(ListModelClasseRunsResponse)

GetModelClassRequest = _reflection.GeneratedProtocolMessageType('GetModelClassRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETMODELCLASSREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.GetModelClassRequest)
  })
_sym_db.RegisterMessage(GetModelClassRequest)

CreateModelClassRequest = _reflection.GeneratedProtocolMessageType('CreateModelClassRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATEMODELCLASSREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.CreateModelClassRequest)
  })
_sym_db.RegisterMessage(CreateModelClassRequest)

UpdateModelClassRequest = _reflection.GeneratedProtocolMessageType('UpdateModelClassRequest', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEMODELCLASSREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.UpdateModelClassRequest)
  })
_sym_db.RegisterMessage(UpdateModelClassRequest)

DeleteModelClassRequest = _reflection.GeneratedProtocolMessageType('DeleteModelClassRequest', (_message.Message,), {
  'DESCRIPTOR' : _DELETEMODELCLASSREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.DeleteModelClassRequest)
  })
_sym_db.RegisterMessage(DeleteModelClassRequest)

GetModelClassRunRequest = _reflection.GeneratedProtocolMessageType('GetModelClassRunRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETMODELCLASSRUNREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.GetModelClassRunRequest)
  })
_sym_db.RegisterMessage(GetModelClassRunRequest)

CreateModelClassRunRequest = _reflection.GeneratedProtocolMessageType('CreateModelClassRunRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATEMODELCLASSRUNREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.CreateModelClassRunRequest)
  })
_sym_db.RegisterMessage(CreateModelClassRunRequest)

UpdateModelClassRunRequest = _reflection.GeneratedProtocolMessageType('UpdateModelClassRunRequest', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEMODELCLASSRUNREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.UpdateModelClassRunRequest)
  })
_sym_db.RegisterMessage(UpdateModelClassRunRequest)

DeleteModelClassRunRequest = _reflection.GeneratedProtocolMessageType('DeleteModelClassRunRequest', (_message.Message,), {
  'DESCRIPTOR' : _DELETEMODELCLASSRUNREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.DeleteModelClassRunRequest)
  })
_sym_db.RegisterMessage(DeleteModelClassRunRequest)

ListFeatureHistogramsRequest = _reflection.GeneratedProtocolMessageType('ListFeatureHistogramsRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTFEATUREHISTOGRAMSREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.ListFeatureHistogramsRequest)
  })
_sym_db.RegisterMessage(ListFeatureHistogramsRequest)

ListFeatureHistogramsResponse = _reflection.GeneratedProtocolMessageType('ListFeatureHistogramsResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTFEATUREHISTOGRAMSRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.ListFeatureHistogramsResponse)
  })
_sym_db.RegisterMessage(ListFeatureHistogramsResponse)

GetFeatureHistogramRequest = _reflection.GeneratedProtocolMessageType('GetFeatureHistogramRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETFEATUREHISTOGRAMREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.GetFeatureHistogramRequest)
  })
_sym_db.RegisterMessage(GetFeatureHistogramRequest)

CreateFeatureHistogramRequest = _reflection.GeneratedProtocolMessageType('CreateFeatureHistogramRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATEFEATUREHISTOGRAMREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.CreateFeatureHistogramRequest)
  })
_sym_db.RegisterMessage(CreateFeatureHistogramRequest)

UpdateFeatureHistogramRequest = _reflection.GeneratedProtocolMessageType('UpdateFeatureHistogramRequest', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEFEATUREHISTOGRAMREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.UpdateFeatureHistogramRequest)
  })
_sym_db.RegisterMessage(UpdateFeatureHistogramRequest)

DeleteFeatureHistogramRequest = _reflection.GeneratedProtocolMessageType('DeleteFeatureHistogramRequest', (_message.Message,), {
  'DESCRIPTOR' : _DELETEFEATUREHISTOGRAMREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.DeleteFeatureHistogramRequest)
  })
_sym_db.RegisterMessage(DeleteFeatureHistogramRequest)

ListFeatureGroupRequest = _reflection.GeneratedProtocolMessageType('ListFeatureGroupRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTFEATUREGROUPREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.ListFeatureGroupRequest)
  })
_sym_db.RegisterMessage(ListFeatureGroupRequest)

ListFeatureGroupResponse = _reflection.GeneratedProtocolMessageType('ListFeatureGroupResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTFEATUREGROUPRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.ListFeatureGroupResponse)
  })
_sym_db.RegisterMessage(ListFeatureGroupResponse)

GetFeatureGroupRequest = _reflection.GeneratedProtocolMessageType('GetFeatureGroupRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETFEATUREGROUPREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.GetFeatureGroupRequest)
  })
_sym_db.RegisterMessage(GetFeatureGroupRequest)

CreateFeatureGroupRequest = _reflection.GeneratedProtocolMessageType('CreateFeatureGroupRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATEFEATUREGROUPREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.CreateFeatureGroupRequest)
  })
_sym_db.RegisterMessage(CreateFeatureGroupRequest)

UpdateFeatureGroupRequest = _reflection.GeneratedProtocolMessageType('UpdateFeatureGroupRequest', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEFEATUREGROUPREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.UpdateFeatureGroupRequest)
  })
_sym_db.RegisterMessage(UpdateFeatureGroupRequest)

DeleteFeatureGroupRequest = _reflection.GeneratedProtocolMessageType('DeleteFeatureGroupRequest', (_message.Message,), {
  'DESCRIPTOR' : _DELETEFEATUREGROUPREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.DeleteFeatureGroupRequest)
  })
_sym_db.RegisterMessage(DeleteFeatureGroupRequest)

ListRecipesRequest = _reflection.GeneratedProtocolMessageType('ListRecipesRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTRECIPESREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.ListRecipesRequest)
  })
_sym_db.RegisterMessage(ListRecipesRequest)

ListRecipesResponse = _reflection.GeneratedProtocolMessageType('ListRecipesResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTRECIPESRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.ListRecipesResponse)
  })
_sym_db.RegisterMessage(ListRecipesResponse)

GetRecipeRequest = _reflection.GeneratedProtocolMessageType('GetRecipeRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETRECIPEREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.GetRecipeRequest)
  })
_sym_db.RegisterMessage(GetRecipeRequest)

CreateRecipeRequest = _reflection.GeneratedProtocolMessageType('CreateRecipeRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATERECIPEREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.CreateRecipeRequest)
  })
_sym_db.RegisterMessage(CreateRecipeRequest)

UpdateRecipeRequest = _reflection.GeneratedProtocolMessageType('UpdateRecipeRequest', (_message.Message,), {
  'DESCRIPTOR' : _UPDATERECIPEREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.UpdateRecipeRequest)
  })
_sym_db.RegisterMessage(UpdateRecipeRequest)

DeleteRecipeRequest = _reflection.GeneratedProtocolMessageType('DeleteRecipeRequest', (_message.Message,), {
  'DESCRIPTOR' : _DELETERECIPEREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.DeleteRecipeRequest)
  })
_sym_db.RegisterMessage(DeleteRecipeRequest)

ListRecipeRunsRequest = _reflection.GeneratedProtocolMessageType('ListRecipeRunsRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTRECIPERUNSREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.ListRecipeRunsRequest)
  })
_sym_db.RegisterMessage(ListRecipeRunsRequest)

ListRecipeRunsResponse = _reflection.GeneratedProtocolMessageType('ListRecipeRunsResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTRECIPERUNSRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.ListRecipeRunsResponse)
  })
_sym_db.RegisterMessage(ListRecipeRunsResponse)

GetRecipeRunRequest = _reflection.GeneratedProtocolMessageType('GetRecipeRunRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETRECIPERUNREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.GetRecipeRunRequest)
  })
_sym_db.RegisterMessage(GetRecipeRunRequest)

CreateRecipeRunRequest = _reflection.GeneratedProtocolMessageType('CreateRecipeRunRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATERECIPERUNREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.CreateRecipeRunRequest)
  })
_sym_db.RegisterMessage(CreateRecipeRunRequest)

UpdateRecipeRunRequest = _reflection.GeneratedProtocolMessageType('UpdateRecipeRunRequest', (_message.Message,), {
  'DESCRIPTOR' : _UPDATERECIPERUNREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.UpdateRecipeRunRequest)
  })
_sym_db.RegisterMessage(UpdateRecipeRunRequest)

DeleteRecipeRunRequest = _reflection.GeneratedProtocolMessageType('DeleteRecipeRunRequest', (_message.Message,), {
  'DESCRIPTOR' : _DELETERECIPERUNREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.DeleteRecipeRunRequest)
  })
_sym_db.RegisterMessage(DeleteRecipeRunRequest)

ListModelsRequest = _reflection.GeneratedProtocolMessageType('ListModelsRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTMODELSREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.ListModelsRequest)
  })
_sym_db.RegisterMessage(ListModelsRequest)

ListModelsResponse = _reflection.GeneratedProtocolMessageType('ListModelsResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTMODELSRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.ListModelsResponse)
  })
_sym_db.RegisterMessage(ListModelsResponse)

GetModelRequest = _reflection.GeneratedProtocolMessageType('GetModelRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETMODELREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.GetModelRequest)
  })
_sym_db.RegisterMessage(GetModelRequest)

CreateModelRequest = _reflection.GeneratedProtocolMessageType('CreateModelRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATEMODELREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.CreateModelRequest)
  })
_sym_db.RegisterMessage(CreateModelRequest)

UpdateModelRequest = _reflection.GeneratedProtocolMessageType('UpdateModelRequest', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEMODELREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.UpdateModelRequest)
  })
_sym_db.RegisterMessage(UpdateModelRequest)

DeleteModelRequest = _reflection.GeneratedProtocolMessageType('DeleteModelRequest', (_message.Message,), {
  'DESCRIPTOR' : _DELETEMODELREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.DeleteModelRequest)
  })
_sym_db.RegisterMessage(DeleteModelRequest)

ListReportsRequest = _reflection.GeneratedProtocolMessageType('ListReportsRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTREPORTSREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.ListReportsRequest)
  })
_sym_db.RegisterMessage(ListReportsRequest)

ListReportsResponse = _reflection.GeneratedProtocolMessageType('ListReportsResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTREPORTSRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.ListReportsResponse)
  })
_sym_db.RegisterMessage(ListReportsResponse)

GetReportRequest = _reflection.GeneratedProtocolMessageType('GetReportRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETREPORTREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.GetReportRequest)
  })
_sym_db.RegisterMessage(GetReportRequest)

CreateReportRequest = _reflection.GeneratedProtocolMessageType('CreateReportRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATEREPORTREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.CreateReportRequest)
  })
_sym_db.RegisterMessage(CreateReportRequest)

UpdateReportRequest = _reflection.GeneratedProtocolMessageType('UpdateReportRequest', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEREPORTREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.UpdateReportRequest)
  })
_sym_db.RegisterMessage(UpdateReportRequest)

DeleteReportRequest = _reflection.GeneratedProtocolMessageType('DeleteReportRequest', (_message.Message,), {
  'DESCRIPTOR' : _DELETEREPORTREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.DeleteReportRequest)
  })
_sym_db.RegisterMessage(DeleteReportRequest)

ListStudiesRequest = _reflection.GeneratedProtocolMessageType('ListStudiesRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTSTUDIESREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.ListStudiesRequest)
  })
_sym_db.RegisterMessage(ListStudiesRequest)

ListStudiesResponse = _reflection.GeneratedProtocolMessageType('ListStudiesResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTSTUDIESRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.ListStudiesResponse)
  })
_sym_db.RegisterMessage(ListStudiesResponse)

GetStudyRequest = _reflection.GeneratedProtocolMessageType('GetStudyRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETSTUDYREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.GetStudyRequest)
  })
_sym_db.RegisterMessage(GetStudyRequest)

CreateStudyRequest = _reflection.GeneratedProtocolMessageType('CreateStudyRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATESTUDYREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.CreateStudyRequest)
  })
_sym_db.RegisterMessage(CreateStudyRequest)

UpdateStudyRequest = _reflection.GeneratedProtocolMessageType('UpdateStudyRequest', (_message.Message,), {
  'DESCRIPTOR' : _UPDATESTUDYREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.UpdateStudyRequest)
  })
_sym_db.RegisterMessage(UpdateStudyRequest)

DeleteStudyRequest = _reflection.GeneratedProtocolMessageType('DeleteStudyRequest', (_message.Message,), {
  'DESCRIPTOR' : _DELETESTUDYREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.DeleteStudyRequest)
  })
_sym_db.RegisterMessage(DeleteStudyRequest)

ListPredictionsRequest = _reflection.GeneratedProtocolMessageType('ListPredictionsRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTPREDICTIONSREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.ListPredictionsRequest)
  })
_sym_db.RegisterMessage(ListPredictionsRequest)

ListPredictionsResponse = _reflection.GeneratedProtocolMessageType('ListPredictionsResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTPREDICTIONSRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.ListPredictionsResponse)
  })
_sym_db.RegisterMessage(ListPredictionsResponse)

GetPredictionRequest = _reflection.GeneratedProtocolMessageType('GetPredictionRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETPREDICTIONREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.GetPredictionRequest)
  })
_sym_db.RegisterMessage(GetPredictionRequest)

CreatePredictionRequest = _reflection.GeneratedProtocolMessageType('CreatePredictionRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATEPREDICTIONREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.CreatePredictionRequest)
  })
_sym_db.RegisterMessage(CreatePredictionRequest)

UpdatePredictionRequest = _reflection.GeneratedProtocolMessageType('UpdatePredictionRequest', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEPREDICTIONREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.UpdatePredictionRequest)
  })
_sym_db.RegisterMessage(UpdatePredictionRequest)

DeletePredictionRequest = _reflection.GeneratedProtocolMessageType('DeletePredictionRequest', (_message.Message,), {
  'DESCRIPTOR' : _DELETEPREDICTIONREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.DeletePredictionRequest)
  })
_sym_db.RegisterMessage(DeletePredictionRequest)

ListPredictorsRequest = _reflection.GeneratedProtocolMessageType('ListPredictorsRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTPREDICTORSREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.ListPredictorsRequest)
  })
_sym_db.RegisterMessage(ListPredictorsRequest)

ListPredictorsResponse = _reflection.GeneratedProtocolMessageType('ListPredictorsResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTPREDICTORSRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.ListPredictorsResponse)
  })
_sym_db.RegisterMessage(ListPredictorsResponse)

GetPredictorRequest = _reflection.GeneratedProtocolMessageType('GetPredictorRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETPREDICTORREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.GetPredictorRequest)
  })
_sym_db.RegisterMessage(GetPredictorRequest)

CreatePredictorRequest = _reflection.GeneratedProtocolMessageType('CreatePredictorRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATEPREDICTORREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.CreatePredictorRequest)
  })
_sym_db.RegisterMessage(CreatePredictorRequest)

UpdatePredictorRequest = _reflection.GeneratedProtocolMessageType('UpdatePredictorRequest', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEPREDICTORREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.UpdatePredictorRequest)
  })
_sym_db.RegisterMessage(UpdatePredictorRequest)

DeletePredictorRequest = _reflection.GeneratedProtocolMessageType('DeletePredictorRequest', (_message.Message,), {
  'DESCRIPTOR' : _DELETEPREDICTORREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.DeletePredictorRequest)
  })
_sym_db.RegisterMessage(DeletePredictorRequest)

ListReviewsRequest = _reflection.GeneratedProtocolMessageType('ListReviewsRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTREVIEWSREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.ListReviewsRequest)
  })
_sym_db.RegisterMessage(ListReviewsRequest)

ListReviewsResponse = _reflection.GeneratedProtocolMessageType('ListReviewsResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTREVIEWSRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.ListReviewsResponse)
  })
_sym_db.RegisterMessage(ListReviewsResponse)

GetReviewRequest = _reflection.GeneratedProtocolMessageType('GetReviewRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETREVIEWREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.GetReviewRequest)
  })
_sym_db.RegisterMessage(GetReviewRequest)

CreateReviewRequest = _reflection.GeneratedProtocolMessageType('CreateReviewRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATEREVIEWREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.CreateReviewRequest)
  })
_sym_db.RegisterMessage(CreateReviewRequest)

UpdateReviewRequest = _reflection.GeneratedProtocolMessageType('UpdateReviewRequest', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEREVIEWREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.UpdateReviewRequest)
  })
_sym_db.RegisterMessage(UpdateReviewRequest)

DeleteReviewRequest = _reflection.GeneratedProtocolMessageType('DeleteReviewRequest', (_message.Message,), {
  'DESCRIPTOR' : _DELETEREVIEWREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.DeleteReviewRequest)
  })
_sym_db.RegisterMessage(DeleteReviewRequest)

ListPostMortemsRequest = _reflection.GeneratedProtocolMessageType('ListPostMortemsRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTPOSTMORTEMSREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.ListPostMortemsRequest)
  })
_sym_db.RegisterMessage(ListPostMortemsRequest)

ListPostMortemsResponse = _reflection.GeneratedProtocolMessageType('ListPostMortemsResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTPOSTMORTEMSRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.ListPostMortemsResponse)
  })
_sym_db.RegisterMessage(ListPostMortemsResponse)

GetPostMortemRequest = _reflection.GeneratedProtocolMessageType('GetPostMortemRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETPOSTMORTEMREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.GetPostMortemRequest)
  })
_sym_db.RegisterMessage(GetPostMortemRequest)

CreatePostMortemRequest = _reflection.GeneratedProtocolMessageType('CreatePostMortemRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATEPOSTMORTEMREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.CreatePostMortemRequest)
  })
_sym_db.RegisterMessage(CreatePostMortemRequest)

UpdatePostMortemRequest = _reflection.GeneratedProtocolMessageType('UpdatePostMortemRequest', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEPOSTMORTEMREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.UpdatePostMortemRequest)
  })
_sym_db.RegisterMessage(UpdatePostMortemRequest)

DeletePostMortemRequest = _reflection.GeneratedProtocolMessageType('DeletePostMortemRequest', (_message.Message,), {
  'DESCRIPTOR' : _DELETEPOSTMORTEMREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.DeletePostMortemRequest)
  })
_sym_db.RegisterMessage(DeletePostMortemRequest)

ListRunbooksRequest = _reflection.GeneratedProtocolMessageType('ListRunbooksRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTRUNBOOKSREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.ListRunbooksRequest)
  })
_sym_db.RegisterMessage(ListRunbooksRequest)

ListRunbooksResponse = _reflection.GeneratedProtocolMessageType('ListRunbooksResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTRUNBOOKSRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.ListRunbooksResponse)
  })
_sym_db.RegisterMessage(ListRunbooksResponse)

GetRunbookRequest = _reflection.GeneratedProtocolMessageType('GetRunbookRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETRUNBOOKREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.GetRunbookRequest)
  })
_sym_db.RegisterMessage(GetRunbookRequest)

CreateRunbookRequest = _reflection.GeneratedProtocolMessageType('CreateRunbookRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATERUNBOOKREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.CreateRunbookRequest)
  })
_sym_db.RegisterMessage(CreateRunbookRequest)

UpdateRunbookRequest = _reflection.GeneratedProtocolMessageType('UpdateRunbookRequest', (_message.Message,), {
  'DESCRIPTOR' : _UPDATERUNBOOKREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.UpdateRunbookRequest)
  })
_sym_db.RegisterMessage(UpdateRunbookRequest)

DeleteRunbookRequest = _reflection.GeneratedProtocolMessageType('DeleteRunbookRequest', (_message.Message,), {
  'DESCRIPTOR' : _DELETERUNBOOKREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.DeleteRunbookRequest)
  })
_sym_db.RegisterMessage(DeleteRunbookRequest)

ListDataAppRequest = _reflection.GeneratedProtocolMessageType('ListDataAppRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTDATAAPPREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.ListDataAppRequest)
  })
_sym_db.RegisterMessage(ListDataAppRequest)

ListDataAppResponse = _reflection.GeneratedProtocolMessageType('ListDataAppResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTDATAAPPRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.ListDataAppResponse)
  })
_sym_db.RegisterMessage(ListDataAppResponse)

GetDataAppRequest = _reflection.GeneratedProtocolMessageType('GetDataAppRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETDATAAPPREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.GetDataAppRequest)
  })
_sym_db.RegisterMessage(GetDataAppRequest)

CreateDataAppRequest = _reflection.GeneratedProtocolMessageType('CreateDataAppRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATEDATAAPPREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.CreateDataAppRequest)
  })
_sym_db.RegisterMessage(CreateDataAppRequest)

UpdateDataAppRequest = _reflection.GeneratedProtocolMessageType('UpdateDataAppRequest', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEDATAAPPREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.UpdateDataAppRequest)
  })
_sym_db.RegisterMessage(UpdateDataAppRequest)

DeleteDataAppRequest = _reflection.GeneratedProtocolMessageType('DeleteDataAppRequest', (_message.Message,), {
  'DESCRIPTOR' : _DELETEDATAAPPREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.DeleteDataAppRequest)
  })
_sym_db.RegisterMessage(DeleteDataAppRequest)

_DATABASEPROXYSERVICE = DESCRIPTOR.services_by_name['DatabaseProxyService']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z2github.com/metaprov/modelaapi/services/dbproxyd/v1'
  _LISTACCOUNTSREQUEST._serialized_start=540
  _LISTACCOUNTSREQUEST._serialized_end=619
  _LISTACCOUNTSRESPONSE._serialized_start=621
  _LISTACCOUNTSRESPONSE._serialized_end=747
  _GETACCOUNTREQUEST._serialized_start=749
  _GETACCOUNTREQUEST._serialized_end=801
  _CREATEACCOUNTREQUEST._serialized_start=803
  _CREATEACCOUNTREQUEST._serialized_end=903
  _UPDATEACCOUNTREQUEST._serialized_start=905
  _UPDATEACCOUNTREQUEST._serialized_end=1005
  _DELETEACCOUNTREQUEST._serialized_start=1007
  _DELETEACCOUNTREQUEST._serialized_end=1062
  _LISTALERTSREQUEST._serialized_start=1064
  _LISTALERTSREQUEST._serialized_end=1141
  _LISTALERTSRESPONSE._serialized_start=1143
  _LISTALERTSRESPONSE._serialized_end=1265
  _GETALERTREQUEST._serialized_start=1267
  _GETALERTREQUEST._serialized_end=1317
  _CREATEALERTREQUEST._serialized_start=1319
  _CREATEALERTREQUEST._serialized_end=1415
  _UPDATEALERTREQUEST._serialized_start=1417
  _UPDATEALERTREQUEST._serialized_end=1513
  _DELETEALERTREQUEST._serialized_start=1515
  _DELETEALERTREQUEST._serialized_end=1568
  _LISTATTACHMENTSREQUEST._serialized_start=1570
  _LISTATTACHMENTSREQUEST._serialized_end=1652
  _LISTATTACHMENTSRESPONSE._serialized_start=1655
  _LISTATTACHMENTSRESPONSE._serialized_end=1787
  _GETATTACHMENTREQUEST._serialized_start=1789
  _GETATTACHMENTREQUEST._serialized_end=1844
  _CREATEATTACHMENTREQUEST._serialized_start=1846
  _CREATEATTACHMENTREQUEST._serialized_end=1952
  _UPDATEATTACHMENTREQUEST._serialized_start=1954
  _UPDATEATTACHMENTREQUEST._serialized_end=2060
  _DELETEATTACHMENTREQUEST._serialized_start=2062
  _DELETEATTACHMENTREQUEST._serialized_end=2120
  _LISTTODOSREQUEST._serialized_start=2122
  _LISTTODOSREQUEST._serialized_end=2198
  _LISTTODOSRESPONSE._serialized_start=2200
  _LISTTODOSRESPONSE._serialized_end=2319
  _GETTODOREQUEST._serialized_start=2321
  _GETTODOREQUEST._serialized_end=2370
  _CREATETODOREQUEST._serialized_start=2372
  _CREATETODOREQUEST._serialized_end=2465
  _UPDATETODOREQUEST._serialized_start=2467
  _UPDATETODOREQUEST._serialized_end=2560
  _DELETETODOREQUEST._serialized_start=2562
  _DELETETODOREQUEST._serialized_end=2614
  _LISTCONNECTIONSREQUEST._serialized_start=2616
  _LISTCONNECTIONSREQUEST._serialized_end=2698
  _LISTCONNECTIONSRESPONSE._serialized_start=2701
  _LISTCONNECTIONSRESPONSE._serialized_end=2833
  _GETCONNECTIONREQUEST._serialized_start=2835
  _GETCONNECTIONREQUEST._serialized_end=2890
  _CREATECONNECTIONREQUEST._serialized_start=2892
  _CREATECONNECTIONREQUEST._serialized_end=2998
  _UPDATECONNECTIONREQUEST._serialized_start=3000
  _UPDATECONNECTIONREQUEST._serialized_end=3106
  _DELETECONNECTIONREQUEST._serialized_start=3108
  _DELETECONNECTIONREQUEST._serialized_end=3166
  _LISTLABSREQUEST._serialized_start=3168
  _LISTLABSREQUEST._serialized_end=3243
  _LISTLABSRESPONSE._serialized_start=3245
  _LISTLABSRESPONSE._serialized_end=3363
  _GETLABREQUEST._serialized_start=3365
  _GETLABREQUEST._serialized_end=3413
  _CREATELABREQUEST._serialized_start=3415
  _CREATELABREQUEST._serialized_end=3507
  _UPDATELABREQUEST._serialized_start=3509
  _UPDATELABREQUEST._serialized_end=3601
  _DELETELABREQUEST._serialized_start=3603
  _DELETELABREQUEST._serialized_end=3654
  _LISTLICENSESREQUEST._serialized_start=3656
  _LISTLICENSESREQUEST._serialized_end=3735
  _LISTLICENSESRESPONSE._serialized_start=3737
  _LISTLICENSESRESPONSE._serialized_end=3863
  _GETLICENSEREQUEST._serialized_start=3865
  _GETLICENSEREQUEST._serialized_end=3917
  _CREATELICENSEREQUEST._serialized_start=3919
  _CREATELICENSEREQUEST._serialized_end=4019
  _UPDATELICENSEREQUEST._serialized_start=4021
  _UPDATELICENSEREQUEST._serialized_end=4121
  _DELETELICENSEREQUEST._serialized_start=4123
  _DELETELICENSEREQUEST._serialized_end=4178
  _LISTNOTIFIERSREQUEST._serialized_start=4180
  _LISTNOTIFIERSREQUEST._serialized_end=4260
  _LISTNOTIFIERSRESPONSE._serialized_start=4263
  _LISTNOTIFIERSRESPONSE._serialized_end=4391
  _GETNOTIFIERREQUEST._serialized_start=4393
  _GETNOTIFIERREQUEST._serialized_end=4446
  _CREATENOTIFIERREQUEST._serialized_start=4448
  _CREATENOTIFIERREQUEST._serialized_end=4550
  _UPDATENOTIFIERREQUEST._serialized_start=4552
  _UPDATENOTIFIERREQUEST._serialized_end=4654
  _DELETENOTIFIERREQUEST._serialized_start=4656
  _DELETENOTIFIERREQUEST._serialized_end=4712
  _LISTSERVINGSITESREQUEST._serialized_start=4714
  _LISTSERVINGSITESREQUEST._serialized_end=4797
  _LISTSERVINGSITESRESPONSE._serialized_start=4800
  _LISTSERVINGSITESRESPONSE._serialized_end=4934
  _GETSERVINGSITEREQUEST._serialized_start=4936
  _GETSERVINGSITEREQUEST._serialized_end=4992
  _CREATESERVINGSITEREQUEST._serialized_start=4994
  _CREATESERVINGSITEREQUEST._serialized_end=5102
  _UPDATESERVINGSITEREQUEST._serialized_start=5104
  _UPDATESERVINGSITEREQUEST._serialized_end=5212
  _DELETESERVINGSITEREQUEST._serialized_start=5214
  _DELETESERVINGSITEREQUEST._serialized_end=5273
  _LISTTENANTSREQUEST._serialized_start=5275
  _LISTTENANTSREQUEST._serialized_end=5353
  _LISTTENANTSRESPONSE._serialized_start=5355
  _LISTTENANTSRESPONSE._serialized_end=5479
  _GETTENANTREQUEST._serialized_start=5481
  _GETTENANTREQUEST._serialized_end=5532
  _CREATETENANTREQUEST._serialized_start=5534
  _CREATETENANTREQUEST._serialized_end=5632
  _UPDATETENANTREQUEST._serialized_start=5634
  _UPDATETENANTREQUEST._serialized_end=5732
  _DELETETENANTREQUEST._serialized_start=5734
  _DELETETENANTREQUEST._serialized_end=5788
  _LISTVIRTUALBUCKETSREQUEST._serialized_start=5790
  _LISTVIRTUALBUCKETSREQUEST._serialized_end=5875
  _LISTVIRTUALBUCKETSRESPONSE._serialized_start=5878
  _LISTVIRTUALBUCKETSRESPONSE._serialized_end=6016
  _GETVIRTUALBUCKETREQUEST._serialized_start=6018
  _GETVIRTUALBUCKETREQUEST._serialized_end=6076
  _CREATEVIRTUALBUCKETREQUEST._serialized_start=6078
  _CREATEVIRTUALBUCKETREQUEST._serialized_end=6190
  _UPDATEVIRTUALBUCKETREQUEST._serialized_start=6192
  _UPDATEVIRTUALBUCKETREQUEST._serialized_end=6304
  _DELETEVIRTUALBUCKETREQUEST._serialized_start=6306
  _DELETEVIRTUALBUCKETREQUEST._serialized_end=6367
  _LISTDATAPIPELINESREQUEST._serialized_start=6369
  _LISTDATAPIPELINESREQUEST._serialized_end=6453
  _LISTDATAPIPELINESRESPONSE._serialized_start=6456
  _LISTDATAPIPELINESRESPONSE._serialized_end=6591
  _GETDATAPIPELINEREQUEST._serialized_start=6593
  _GETDATAPIPELINEREQUEST._serialized_end=6650
  _CREATEDATAPIPELINEREQUEST._serialized_start=6652
  _CREATEDATAPIPELINEREQUEST._serialized_end=6761
  _UPDATEDATAPIPELINEREQUEST._serialized_start=6763
  _UPDATEDATAPIPELINEREQUEST._serialized_end=6872
  _DELETEDATAPIPELINEREQUEST._serialized_start=6874
  _DELETEDATAPIPELINEREQUEST._serialized_end=6934
  _LISTDATAPIPELINERUNSREQUEST._serialized_start=6936
  _LISTDATAPIPELINERUNSREQUEST._serialized_end=7023
  _LISTDATAPIPELINERUNSRESPONSE._serialized_start=7026
  _LISTDATAPIPELINERUNSRESPONSE._serialized_end=7167
  _GETDATAPIPELINERUNREQUEST._serialized_start=7169
  _GETDATAPIPELINERUNREQUEST._serialized_end=7229
  _CREATEDATAPIPELINERUNREQUEST._serialized_start=7231
  _CREATEDATAPIPELINERUNREQUEST._serialized_end=7346
  _UPDATEDATAPIPELINERUNREQUEST._serialized_start=7348
  _UPDATEDATAPIPELINERUNREQUEST._serialized_end=7463
  _DELETEDATAPIPELINERUNREQUEST._serialized_start=7465
  _DELETEDATAPIPELINERUNREQUEST._serialized_end=7528
  _LISTDATAPRODUCTSREQUEST._serialized_start=7530
  _LISTDATAPRODUCTSREQUEST._serialized_end=7613
  _LISTDATAPRODUCTSRESPONSE._serialized_start=7616
  _LISTDATAPRODUCTSRESPONSE._serialized_end=7749
  _GETDATAPRODUCTREQUEST._serialized_start=7751
  _GETDATAPRODUCTREQUEST._serialized_end=7807
  _CREATEDATAPRODUCTREQUEST._serialized_start=7809
  _CREATEDATAPRODUCTREQUEST._serialized_end=7916
  _UPDATEDATAPRODUCTREQUEST._serialized_start=7918
  _UPDATEDATAPRODUCTREQUEST._serialized_end=8025
  _DELETEDATAPRODUCTREQUEST._serialized_start=8027
  _DELETEDATAPRODUCTREQUEST._serialized_end=8086
  _LISTDATAPRODUCTVERSIONSREQUEST._serialized_start=8088
  _LISTDATAPRODUCTVERSIONSREQUEST._serialized_end=8178
  _LISTDATAPRODUCTVERSIONSRESPONSE._serialized_start=8181
  _LISTDATAPRODUCTVERSIONSRESPONSE._serialized_end=8328
  _GETDATAPRODUCTVERSIONREQUEST._serialized_start=8330
  _GETDATAPRODUCTVERSIONREQUEST._serialized_end=8393
  _CREATEDATAPRODUCTVERSIONREQUEST._serialized_start=8395
  _CREATEDATAPRODUCTVERSIONREQUEST._serialized_end=8516
  _UPDATEDATAPRODUCTVERSIONREQUEST._serialized_start=8518
  _UPDATEDATAPRODUCTVERSIONREQUEST._serialized_end=8639
  _DELETEDATAPRODUCTVERSIONREQUEST._serialized_start=8641
  _DELETEDATAPRODUCTVERSIONREQUEST._serialized_end=8707
  _LISTDATASETSREQUEST._serialized_start=8709
  _LISTDATASETSREQUEST._serialized_end=8788
  _LISTDATASETSRESPONSE._serialized_start=8790
  _LISTDATASETSRESPONSE._serialized_end=8915
  _GETDATASETREQUEST._serialized_start=8917
  _GETDATASETREQUEST._serialized_end=8969
  _CREATEDATASETREQUEST._serialized_start=8971
  _CREATEDATASETREQUEST._serialized_end=9070
  _UPDATEDATASETREQUEST._serialized_start=9072
  _UPDATEDATASETREQUEST._serialized_end=9171
  _DELETEDATASETREQUEST._serialized_start=9173
  _DELETEDATASETREQUEST._serialized_end=9228
  _LISTDATASOURCESREQUEST._serialized_start=9230
  _LISTDATASOURCESREQUEST._serialized_end=9312
  _LISTDATASOURCESRESPONSE._serialized_start=9315
  _LISTDATASOURCESRESPONSE._serialized_end=9446
  _GETDATASOURCEREQUEST._serialized_start=9448
  _GETDATASOURCEREQUEST._serialized_end=9503
  _CREATEDATASOURCEREQUEST._serialized_start=9505
  _CREATEDATASOURCEREQUEST._serialized_end=9610
  _UPDATEDATASOURCEREQUEST._serialized_start=9612
  _UPDATEDATASOURCEREQUEST._serialized_end=9717
  _DELETEDATASOURCEREQUEST._serialized_start=9719
  _DELETEDATASOURCEREQUEST._serialized_end=9777
  _LISTENTITIESREQUEST._serialized_start=9779
  _LISTENTITIESREQUEST._serialized_end=9858
  _LISTENTITIESRESPONSE._serialized_start=9860
  _LISTENTITIESRESPONSE._serialized_end=9984
  _GETENTITYREQUEST._serialized_start=9986
  _GETENTITYREQUEST._serialized_end=10037
  _CREATEENTITYREQUEST._serialized_start=10039
  _CREATEENTITYREQUEST._serialized_end=10136
  _UPDATEENTITYREQUEST._serialized_start=10138
  _UPDATEENTITYREQUEST._serialized_end=10235
  _DELETEENTITYREQUEST._serialized_start=10237
  _DELETEENTITYREQUEST._serialized_end=10291
  _LISTMODELCLASSESREQUEST._serialized_start=10293
  _LISTMODELCLASSESREQUEST._serialized_end=10376
  _LISTMODELCLASSESRESPONSE._serialized_start=10379
  _LISTMODELCLASSESRESPONSE._serialized_end=10515
  _LISTMODELCLASSESRUNREQUEST._serialized_start=10517
  _LISTMODELCLASSESRUNREQUEST._serialized_end=10603
  _LISTMODELCLASSERUNSRESPONSE._serialized_start=10606
  _LISTMODELCLASSERUNSRESPONSE._serialized_end=10748
  _GETMODELCLASSREQUEST._serialized_start=10750
  _GETMODELCLASSREQUEST._serialized_end=10805
  _CREATEMODELCLASSREQUEST._serialized_start=10807
  _CREATEMODELCLASSREQUEST._serialized_end=10916
  _UPDATEMODELCLASSREQUEST._serialized_start=10918
  _UPDATEMODELCLASSREQUEST._serialized_end=11027
  _DELETEMODELCLASSREQUEST._serialized_start=11029
  _DELETEMODELCLASSREQUEST._serialized_end=11087
  _GETMODELCLASSRUNREQUEST._serialized_start=11089
  _GETMODELCLASSRUNREQUEST._serialized_end=11147
  _CREATEMODELCLASSRUNREQUEST._serialized_start=11149
  _CREATEMODELCLASSRUNREQUEST._serialized_end=11264
  _UPDATEMODELCLASSRUNREQUEST._serialized_start=11266
  _UPDATEMODELCLASSRUNREQUEST._serialized_end=11381
  _DELETEMODELCLASSRUNREQUEST._serialized_start=11383
  _DELETEMODELCLASSRUNREQUEST._serialized_end=11444
  _LISTFEATUREHISTOGRAMSREQUEST._serialized_start=11446
  _LISTFEATUREHISTOGRAMSREQUEST._serialized_end=11534
  _LISTFEATUREHISTOGRAMSRESPONSE._serialized_start=11537
  _LISTFEATUREHISTOGRAMSRESPONSE._serialized_end=11680
  _GETFEATUREHISTOGRAMREQUEST._serialized_start=11682
  _GETFEATUREHISTOGRAMREQUEST._serialized_end=11743
  _CREATEFEATUREHISTOGRAMREQUEST._serialized_start=11745
  _CREATEFEATUREHISTOGRAMREQUEST._serialized_end=11862
  _UPDATEFEATUREHISTOGRAMREQUEST._serialized_start=11864
  _UPDATEFEATUREHISTOGRAMREQUEST._serialized_end=11981
  _DELETEFEATUREHISTOGRAMREQUEST._serialized_start=11983
  _DELETEFEATUREHISTOGRAMREQUEST._serialized_end=12047
  _LISTFEATUREGROUPREQUEST._serialized_start=12049
  _LISTFEATUREGROUPREQUEST._serialized_end=12132
  _LISTFEATUREGROUPRESPONSE._serialized_start=12135
  _LISTFEATUREGROUPRESPONSE._serialized_end=12269
  _GETFEATUREGROUPREQUEST._serialized_start=12271
  _GETFEATUREGROUPREQUEST._serialized_end=12328
  _CREATEFEATUREGROUPREQUEST._serialized_start=12330
  _CREATEFEATUREGROUPREQUEST._serialized_end=12439
  _UPDATEFEATUREGROUPREQUEST._serialized_start=12441
  _UPDATEFEATUREGROUPREQUEST._serialized_end=12550
  _DELETEFEATUREGROUPREQUEST._serialized_start=12552
  _DELETEFEATUREGROUPREQUEST._serialized_end=12612
  _LISTRECIPESREQUEST._serialized_start=12614
  _LISTRECIPESREQUEST._serialized_end=12692
  _LISTRECIPESRESPONSE._serialized_start=12694
  _LISTRECIPESRESPONSE._serialized_end=12817
  _GETRECIPEREQUEST._serialized_start=12819
  _GETRECIPEREQUEST._serialized_end=12870
  _CREATERECIPEREQUEST._serialized_start=12872
  _CREATERECIPEREQUEST._serialized_end=12969
  _UPDATERECIPEREQUEST._serialized_start=12971
  _UPDATERECIPEREQUEST._serialized_end=13068
  _DELETERECIPEREQUEST._serialized_start=13070
  _DELETERECIPEREQUEST._serialized_end=13124
  _LISTRECIPERUNSREQUEST._serialized_start=13126
  _LISTRECIPERUNSREQUEST._serialized_end=13207
  _LISTRECIPERUNSRESPONSE._serialized_start=13210
  _LISTRECIPERUNSRESPONSE._serialized_end=13339
  _GETRECIPERUNREQUEST._serialized_start=13341
  _GETRECIPERUNREQUEST._serialized_end=13395
  _CREATERECIPERUNREQUEST._serialized_start=13397
  _CREATERECIPERUNREQUEST._serialized_end=13500
  _UPDATERECIPERUNREQUEST._serialized_start=13502
  _UPDATERECIPERUNREQUEST._serialized_end=13605
  _DELETERECIPERUNREQUEST._serialized_start=13607
  _DELETERECIPERUNREQUEST._serialized_end=13664
  _LISTMODELSREQUEST._serialized_start=13666
  _LISTMODELSREQUEST._serialized_end=13743
  _LISTMODELSRESPONSE._serialized_start=13745
  _LISTMODELSRESPONSE._serialized_end=13870
  _GETMODELREQUEST._serialized_start=13872
  _GETMODELREQUEST._serialized_end=13922
  _CREATEMODELREQUEST._serialized_start=13924
  _CREATEMODELREQUEST._serialized_end=14023
  _UPDATEMODELREQUEST._serialized_start=14025
  _UPDATEMODELREQUEST._serialized_end=14124
  _DELETEMODELREQUEST._serialized_start=14126
  _DELETEMODELREQUEST._serialized_end=14179
  _LISTREPORTSREQUEST._serialized_start=14181
  _LISTREPORTSREQUEST._serialized_end=14259
  _LISTREPORTSRESPONSE._serialized_start=14261
  _LISTREPORTSRESPONSE._serialized_end=14388
  _GETREPORTREQUEST._serialized_start=14390
  _GETREPORTREQUEST._serialized_end=14441
  _CREATEREPORTREQUEST._serialized_start=14443
  _CREATEREPORTREQUEST._serialized_end=14544
  _UPDATEREPORTREQUEST._serialized_start=14546
  _UPDATEREPORTREQUEST._serialized_end=14647
  _DELETEREPORTREQUEST._serialized_start=14649
  _DELETEREPORTREQUEST._serialized_end=14703
  _LISTSTUDIESREQUEST._serialized_start=14705
  _LISTSTUDIESREQUEST._serialized_end=14783
  _LISTSTUDIESRESPONSE._serialized_start=14785
  _LISTSTUDIESRESPONSE._serialized_end=14911
  _GETSTUDYREQUEST._serialized_start=14913
  _GETSTUDYREQUEST._serialized_end=14963
  _CREATESTUDYREQUEST._serialized_start=14965
  _CREATESTUDYREQUEST._serialized_end=15064
  _UPDATESTUDYREQUEST._serialized_start=15066
  _UPDATESTUDYREQUEST._serialized_end=15165
  _DELETESTUDYREQUEST._serialized_start=15167
  _DELETESTUDYREQUEST._serialized_end=15220
  _LISTPREDICTIONSREQUEST._serialized_start=15222
  _LISTPREDICTIONSREQUEST._serialized_end=15304
  _LISTPREDICTIONSRESPONSE._serialized_start=15307
  _LISTPREDICTIONSRESPONSE._serialized_end=15443
  _GETPREDICTIONREQUEST._serialized_start=15445
  _GETPREDICTIONREQUEST._serialized_end=15500
  _CREATEPREDICTIONREQUEST._serialized_start=15502
  _CREATEPREDICTIONREQUEST._serialized_end=15612
  _UPDATEPREDICTIONREQUEST._serialized_start=15614
  _UPDATEPREDICTIONREQUEST._serialized_end=15724
  _DELETEPREDICTIONREQUEST._serialized_start=15726
  _DELETEPREDICTIONREQUEST._serialized_end=15784
  _LISTPREDICTORSREQUEST._serialized_start=15786
  _LISTPREDICTORSREQUEST._serialized_end=15867
  _LISTPREDICTORSRESPONSE._serialized_start=15870
  _LISTPREDICTORSRESPONSE._serialized_end=16004
  _GETPREDICTORREQUEST._serialized_start=16006
  _GETPREDICTORREQUEST._serialized_end=16060
  _CREATEPREDICTORREQUEST._serialized_start=16062
  _CREATEPREDICTORREQUEST._serialized_end=16170
  _UPDATEPREDICTORREQUEST._serialized_start=16172
  _UPDATEPREDICTORREQUEST._serialized_end=16280
  _DELETEPREDICTORREQUEST._serialized_start=16282
  _DELETEPREDICTORREQUEST._serialized_end=16339
  _LISTREVIEWSREQUEST._serialized_start=16341
  _LISTREVIEWSREQUEST._serialized_end=16419
  _LISTREVIEWSRESPONSE._serialized_start=16421
  _LISTREVIEWSRESPONSE._serialized_end=16544
  _GETREVIEWREQUEST._serialized_start=16546
  _GETREVIEWREQUEST._serialized_end=16597
  _CREATEREVIEWREQUEST._serialized_start=16599
  _CREATEREVIEWREQUEST._serialized_end=16696
  _UPDATEREVIEWREQUEST._serialized_start=16698
  _UPDATEREVIEWREQUEST._serialized_end=16795
  _DELETEREVIEWREQUEST._serialized_start=16797
  _DELETEREVIEWREQUEST._serialized_end=16851
  _LISTPOSTMORTEMSREQUEST._serialized_start=16853
  _LISTPOSTMORTEMSREQUEST._serialized_end=16935
  _LISTPOSTMORTEMSRESPONSE._serialized_start=16938
  _LISTPOSTMORTEMSRESPONSE._serialized_end=17069
  _GETPOSTMORTEMREQUEST._serialized_start=17071
  _GETPOSTMORTEMREQUEST._serialized_end=17126
  _CREATEPOSTMORTEMREQUEST._serialized_start=17128
  _CREATEPOSTMORTEMREQUEST._serialized_end=17233
  _UPDATEPOSTMORTEMREQUEST._serialized_start=17235
  _UPDATEPOSTMORTEMREQUEST._serialized_end=17340
  _DELETEPOSTMORTEMREQUEST._serialized_start=17342
  _DELETEPOSTMORTEMREQUEST._serialized_end=17400
  _LISTRUNBOOKSREQUEST._serialized_start=17402
  _LISTRUNBOOKSREQUEST._serialized_end=17481
  _LISTRUNBOOKSRESPONSE._serialized_start=17483
  _LISTRUNBOOKSRESPONSE._serialized_end=17608
  _GETRUNBOOKREQUEST._serialized_start=17610
  _GETRUNBOOKREQUEST._serialized_end=17662
  _CREATERUNBOOKREQUEST._serialized_start=17664
  _CREATERUNBOOKREQUEST._serialized_end=17763
  _UPDATERUNBOOKREQUEST._serialized_start=17765
  _UPDATERUNBOOKREQUEST._serialized_end=17864
  _DELETERUNBOOKREQUEST._serialized_start=17866
  _DELETERUNBOOKREQUEST._serialized_end=17921
  _LISTDATAAPPREQUEST._serialized_start=17923
  _LISTDATAAPPREQUEST._serialized_end=18001
  _LISTDATAAPPRESPONSE._serialized_start=18004
  _LISTDATAAPPRESPONSE._serialized_end=18133
  _GETDATAAPPREQUEST._serialized_start=18135
  _GETDATAAPPREQUEST._serialized_end=18187
  _CREATEDATAAPPREQUEST._serialized_start=18189
  _CREATEDATAAPPREQUEST._serialized_end=18293
  _UPDATEDATAAPPREQUEST._serialized_start=18295
  _UPDATEDATAAPPREQUEST._serialized_end=18399
  _DELETEDATAAPPREQUEST._serialized_start=18401
  _DELETEDATAAPPREQUEST._serialized_end=18456
  _DATABASEPROXYSERVICE._serialized_start=18460
  _DATABASEPROXYSERVICE._serialized_end=44189
# @@protoc_insertion_point(module_scope)
